#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Mapping definitions for pylatinize module.

This file contains dictionaries used by the PyLatinize class to define
transliteration rules for specific Unicode characters and sequences.
"""
from typing import Dict

"""
Default mapping for transliterating characters to ASCII.

Returns:
    A dictionary where keys are base characters and values are lists of special characters.
"""
default_mapping: Dict[str, str] = {
    """
    A dictionary intended to hold default transliteration mappings.

    Keys should be Unicode character sequences (str) and values should be
    their desired ASCII equivalents (str). This mapping serves as a baseline
    for transliteration when no specific or custom mappings are provided
    or matched.
    """
    # Latin
    "\u00c0": "A",  # À
    "\u00c1": "A",  # Á
    "\u00c2": "A",  # Â
    "\u00c3": "A",  # Ã
    "\u00c4": "Ae",  # Ä
    "\u00c5": "A",  # Å
    "\u00c6": "AE",  # Æ
    "\u00c7": "C",  # Ç
    "\u00c8": "E",  # È
    "\u00c9": "E",  # É
    "\u00ca": "E",  # Ê
    "\u00cb": "E",  # Ë
    "\u00cc": "I",  # Ì
    "\u00cd": "I",  # Í
    "\u00ce": "I",  # Î
    "\u00cf": "I",  # Ï
    "\u00d0": "D",  # Ð
    "\u00d1": "N",  # Ñ
    "\u00d2": "O",  # Ò
    "\u00d3": "O",  # Ó
    "\u00d4": "O",  # Ô
    "\u00d5": "O",  # Õ
    "\u00d6": "Oe",  # Ö
    "\u0150": "O",  # Ő
    "\u00d8": "O",  # Ø
    "\u00d9": "U",  # Ù
    "\u00da": "U",  # Ú
    "\u00db": "U",  # Û
    "\u00dc": "Ue",  # Ü
    "\u0170": "U",  # Ű
    "\u00dd": "Y",  # Ý
    "\u00de": "TH",  # Þ
    "\u00df": "ss",  # ß
    "\u00e0": "a",  # à
    "\u00e1": "a",  # á
    "\u00e2": "a",  # â
    "\u00e3": "a",  # ã
    "\u00e4": "ae",  # ä
    "\u00e5": "a",  # å
    "\u00e6": "ae",  # æ
    "\u00e7": "c",  # ç
    "\u00e8": "e",  # è
    "\u00e9": "e",  # é
    "\u00ea": "e",  # ê
    "\u00eb": "e",  # ë
    "\u00ec": "i",  # ì
    "\u00ed": "i",  # í
    "\u00ee": "i",  # î
    "\u00ef": "i",  # ï
    "\u00f0": "d",  # ð
    "\u00f1": "n",  # ñ
    "\u00f2": "o",  # ò
    "\u00f3": "o",  # ó
    "\u00f4": "o",  # ô
    "\u00f5": "o",  # õ
    "\u00f6": "oe",  # ö
    "\u0151": "o",  # ő
    "\u00f8": "o",  # ø
    "\u00f9": "u",  # ù
    "\u00fa": "u",  # ú
    "\u00fb": "u",  # û
    "\u00fc": "ue",  # ü
    "\u0171": "u",  # ű
    "\u00fd": "y",  # ý
    "\u00fe": "th",  # þ
    "\u00ff": "y",  # ÿ
    "\u1e9e": "SS",  # ẞ
    # Vietnamese
    "\u0110": "D",  # Đ
    "\u0111": "d",  # đ
    "\u0129": "i",  # ĩ
    "\u0128": "I",  # Ĩ
    "\u0169": "u",  # ũ
    "\u0168": "U",  # Ũ
    "\u01a1": "o",  # ơ
    "\u01a0": "O",  # Ơ
    "\u01b0": "u",  # ư
    "\u01af": "U",  # Ư
    "\u1ea1": "a",  # ạ
    "\u1ea0": "A",  # Ạ
    "\u1ea3": "a",  # ả
    "\u1ea2": "A",  # Ả
    "\u1ea5": "a",  # ấ
    "\u1ea4": "A",  # Ấ
    "\u1ea7": "a",  # ầ
    "\u1ea6": "A",  # Ầ
    "\u1ea9": "a",  # ẩ
    "\u1ea8": "A",  # Ẩ
    "\u1eab": "a",  # ẫ
    "\u1eaa": "A",  # Ẫ
    "\u1ead": "a",  # ậ
    "\u1eac": "A",  # Ậ
    "\u1eaf": "a",  # ắ
    "\u1eae": "A",  # Ắ
    "\u1eb1": "a",  # ằ
    "\u1eb0": "A",  # Ằ
    "\u1eb3": "a",  # ẳ
    "\u1eb2": "A",  # Ẳ
    "\u1eb5": "a",  # ẵ
    "\u1eb4": "A",  # Ẵ
    "\u1eb7": "a",  # ặ
    "\u1eb6": "A",  # Ặ
    "\u1eb9": "e",  # ẹ
    "\u1eb8": "E",  # Ẹ
    "\u1ebb": "e",  # ẻ
    "\u1eba": "E",  # Ẻ
    "\u1ebd": "e",  # ẽ
    "\u1ebc": "E",  # Ẽ
    "\u1ebf": "e",  # ế
    "\u1ebe": "E",  # Ế
    "\u1ec1": "e",  # ề
    "\u1ec0": "E",  # Ề
    "\u1ec3": "e",  # ể
    "\u1ec2": "E",  # Ể
    "\u1ec5": "e",  # ễ
    "\u1ec4": "E",  # Ễ
    "\u1ec7": "e",  # ệ
    "\u1ec6": "E",  # Ệ
    "\u1ec9": "i",  # ỉ
    "\u1ec8": "I",  # Ỉ
    "\u1ecb": "i",  # ị
    "\u1eca": "I",  # Ị
    "\u1ecd": "o",  # ọ
    "\u1ecc": "O",  # Ọ
    "\u1ecf": "o",  # ỏ
    "\u1ece": "O",  # Ỏ
    "\u1ed1": "o",  # ố
    "\u1ed0": "O",  # Ố
    "\u1ed3": "o",  # ồ
    "\u1ed2": "O",  # Ồ
    "\u1ed5": "o",  # ổ
    "\u1ed4": "O",  # Ổ
    "\u1ed7": "o",  # ỗ
    "\u1ed6": "O",  # Ỗ
    "\u1ed9": "o",  # ộ
    "\u1ed8": "O",  # Ộ
    "\u1edb": "o",  # ớ
    "\u1eda": "O",  # Ớ
    "\u1edd": "o",  # ờ
    "\u1edc": "O",  # Ờ
    "\u1edf": "o",  # ở
    "\u1ede": "O",  # Ở
    "\u1ee1": "o",  # ỡ
    "\u1ee0": "O",  # Ỡ
    "\u1ee3": "o",  # ợ
    "\u1ee2": "O",  # Ợ
    "\u1ee5": "u",  # ụ
    "\u1ee4": "U",  # Ụ
    "\u1ee7": "u",  # ủ
    "\u1ee6": "U",  # Ủ
    "\u1ee9": "u",  # ứ
    "\u1ee8": "U",  # Ứ
    "\u1eeb": "u",  # ừ
    "\u1eea": "U",  # Ừ
    "\u1eed": "u",  # ử
    "\u1eec": "U",  # Ử
    "\u1eef": "u",  # ữ
    "\u1eee": "U",  # Ữ
    "\u1ef1": "u",  # ự
    "\u1ef0": "U",  # Ự
    "\u1ef3": "y",  # ỳ
    "\u1ef2": "Y",  # Ỳ
    "\u1ef5": "y",  # ỵ
    "\u1ef4": "Y",  # Ỵ
    "\u1ef7": "y",  # ỷ
    "\u1ef6": "Y",  # Ỷ
    "\u1ef9": "y",  # ỹ
    "\u1ef8": "Y",  # Ỹ
    # Arabic
    "\u0621": "e",  # ء
    "\u0622": "a",  # آ
    "\u0623": "a",  # أ
    "\u0624": "w",  # ؤ
    "\u0625": "i",  # إ
    "\u0626": "y",  # ئ
    "\u0627": "a",  # ا
    "\u0628": "b",  # ب
    "\u0629": "t",  # ة
    "\u062a": "t",  # ت
    "\u062b": "th",  # ث
    "\u062c": "j",  # ج
    "\u062d": "h",  # ح
    "\u062e": "kh",  # خ
    "\u062f": "d",  # د
    "\u0630": "dh",  # ذ
    "\u0631": "r",  # ر
    "\u0632": "z",  # ز
    "\u0633": "s",  # س
    "\u0634": "sh",  # ش
    "\u0635": "s",  # ص
    "\u0636": "d",  # ض
    "\u0637": "t",  # ط
    "\u0638": "z",  # ظ
    "\u0639": "e",  # ع
    "\u063a": "gh",  # غ
    "\u0640": "_",  # ـ
    "\u0641": "f",  # ف
    "\u0642": "q",  # ق
    "\u0643": "k",  # ك
    "\u0644": "l",  # ل
    "\u0645": "m",  # م
    "\u0646": "n",  # ن
    "\u0647": "h",  # ه
    "\u0648": "w",  # و
    "\u0649": "a",  # ى
    "\u064a": "y",  # ي
    "َ\u200e": "a",  # َ
    "ُ": "u",  # ُ
    "ِ\u200e": "i",  # ِ
    "\u0660": "0",  # ٠
    "\u0661": "1",  # ١
    "\u0662": "2",  # ٢
    "\u0663": "3",  # ٣
    "\u0664": "4",  # ٤
    "\u0665": "5",  # ٥
    "\u0666": "6",  # ٦
    "\u0667": "7",  # ٧
    "\u0668": "8",  # ٨
    "\u0669": "9",  # ٩
    # Persian / Farsi
    "\u0686": "ch",  # چ
    "\u06a9": "k",  # ک
    "\u06af": "g",  # گ
    "\u067e": "p",  # پ
    "\u0698": "zh",  # ژ
    "\u06cc": "y",  # ی
    "\u06f0": "0",  # ۰
    "\u06f1": "1",  # ۱
    "\u06f2": "2",  # ۲
    "\u06f3": "3",  # ۳
    "\u06f4": "4",  # ۴
    "\u06f5": "5",  # ۵
    "\u06f6": "6",  # ۶
    "\u06f7": "7",  # ۷
    "\u06f8": "8",  # ۸
    "\u06f9": "9",  # ۹
    # Pashto
    "\u067c": "p",  # ټ
    "\u0681": "z",  # ځ
    "\u0685": "c",  # څ
    "\u0689": "d",  # ډ
    "\ufeab": "d",  # ﺫ
    "\ufead": "r",  # ﺭ
    "\u0693": "r",  # ړ
    "\ufeaf": "z",  # ﺯ
    "\u0696": "g",  # ږ
    "\u069a": "x",  # ښ
    "\u06ab": "g",  # ګ
    "\u06bc": "n",  # ڼ
    "\u06c0": "e",  # ۀ
    "\u06d0": "e",  # ې
    "\u06cd": "ai",  # ۍ
    # Urdu
    "\u0679": "t",  # ٹ
    "\u0688": "d",  # ڈ
    "\u0691": "r",  # ڑ
    "\u06ba": "n",  # ں
    "\u06c1": "h",  # ہ
    "\u06be": "h",  # ھ
    "\u06d2": "e",  # ے
    # Russian
    "\u0410": "A",  # А
    "\u0430": "a",  # а
    "\u0411": "B",  # Б
    "\u0431": "b",  # б
    "\u0412": "V",  # В
    "\u0432": "v",  # в
    "\u0413": "G",  # Г
    "\u0433": "g",  # г
    "\u0414": "D",  # Д
    "\u0434": "d",  # д
    "\u044a\u0435": "ye",  # ъе
    "\u042a\u0435": "Ye",  # Ъе
    "\u044a\u0415": "yE",  # ъЕ
    "\u042a\u0415": "YE",  # ЪЕ
    "\u0415": "E",  # Е
    "\u0435": "e",  # е
    "\u0401": "Yo",  # Ё
    "\u0451": "yo",  # ё
    "\u0416": "Zh",  # Ж
    "\u0436": "zh",  # ж
    "\u0417": "Z",  # З
    "\u0437": "z",  # з
    "\u0418": "I",  # И
    "\u0438": "i",  # и
    "\u044b\u0439": "iy",  # ый
    "\u042b\u0439": "Iy",  # Ый
    "\u042b\u0419": "IY",  # ЫЙ
    "\u044b\u0419": "iY",  # ыЙ
    "\u0419": "Y",  # Й
    "\u0439": "y",  # й
    "\u041a": "K",  # К
    "\u043a": "k",  # к
    "\u041b": "L",  # Л
    "\u043b": "l",  # л
    "\u041c": "M",  # М
    "\u043c": "m",  # м
    "\u041d": "N",  # Н
    "\u043d": "n",  # н
    "\u041e": "O",  # О
    "\u043e": "o",  # о
    "\u041f": "P",  # П
    "\u043f": "p",  # п
    "\u0420": "R",  # Р
    "\u0440": "r",  # р
    "\u0421": "S",  # С
    "\u0441": "s",  # с
    "\u0422": "T",  # Т
    "\u0442": "t",  # т
    "\u0423": "U",  # У
    "\u0443": "u",  # у
    "\u0424": "F",  # Ф
    "\u0444": "f",  # ф
    "\u0425": "Kh",  # Х
    "\u0445": "kh",  # х
    "\u0426": "Ts",  # Ц
    "\u0446": "ts",  # ц
    "\u0427": "Ch",  # Ч
    "\u0447": "ch",  # ч
    "\u0428": "Sh",  # Ш
    "\u0448": "sh",  # ш
    "\u0429": "Sch",  # Щ
    "\u0449": "sch",  # щ
    "\u042a": "",  # Ъ
    "\u044a": "",  # ъ
    "\u042b": "Y",  # Ы
    "\u044b": "y",  # ы
    "\u042c": "",  # Ь
    "\u044c": "",  # ь
    "\u042d": "E",  # Э
    "\u044d": "e",  # э
    "\u042e": "Yu",  # Ю
    "\u044e": "yu",  # ю
    "\u042f": "Ya",  # Я
    "\u044f": "ya",  # я
    # Romanian
    "\u0103": "a",  # ă
    "\u0102": "A",  # Ă
    "\u0219": "s",  # ș
    "\u0218": "S",  # Ș
    "\u021b": "t",  # ț
    "\u021a": "T",  # Ț
    "\u0163": "t",  # ţ
    "\u0162": "T",  # Ţ
    # Turkish
    "\u015f": "s",  # ş
    "\u015e": "S",  # Ş
    "\u011f": "g",  # ğ
    "\u011e": "G",  # Ğ
    "\u0131": "i",  # ı
    "\u0130": "I",  # İ
    # Armenian
    "\u0561": "a",  # ա
    "\u0531": "A",  # Ա
    "\u0562": "b",  # բ
    "\u0532": "B",  # Բ
    "\u0563": "g",  # գ
    "\u0533": "G",  # Գ
    "\u0564": "d",  # դ
    "\u0534": "D",  # Դ
    "\u0565": "ye",  # ե
    "\u0535": "Ye",  # Ե
    "\u0566": "z",  # զ
    "\u0536": "Z",  # Զ
    "\u0567": "e",  # է
    "\u0537": "E",  # Է
    "\u0568": "y",  # ը
    "\u0538": "Y",  # Ը
    "\u0569": "t",  # թ
    "\u0539": "T",  # Թ
    "\u056a": "zh",  # ժ
    "\u053a": "Zh",  # Ժ
    "\u056b": "i",  # ի
    "\u053b": "I",  # Ի
    "\u056c": "l",  # լ
    "\u053c": "L",  # Լ
    "\u056d": "kh",  # խ
    "\u053d": "Kh",  # Խ
    "\u056e": "ts",  # ծ
    "\u053e": "Ts",  # Ծ
    "\u056f": "k",  # կ
    "\u053f": "K",  # Կ
    "\u0570": "h",  # հ
    "\u0540": "H",  # Հ
    "\u0571": "dz",  # ձ
    "\u0541": "Dz",  # Ձ
    "\u0572": "gh",  # ղ
    "\u0542": "Gh",  # Ղ
    "\u0573": "tch",  # ճ
    "\u0543": "Tch",  # Ճ
    "\u0574": "m",  # մ
    "\u0544": "M",  # Մ
    "\u0575": "y",  # յ
    "\u0545": "Y",  # Յ
    "\u0576": "n",  # ն
    "\u0546": "N",  # Ն
    "\u0577": "sh",  # շ
    "\u0547": "Sh",  # Շ
    "\u0578": "vo",  # ո
    "\u0548": "Vo",  # Ո
    "\u0579": "ch",  # չ
    "\u0549": "Ch",  # Չ
    "\u057a": "p",  # պ
    "\u054a": "P",  # Պ
    "\u057b": "j",  # ջ
    "\u054b": "J",  # Ջ
    "\u057c": "r",  # ռ
    "\u054c": "R",  # Ռ
    "\u057d": "s",  # ս
    "\u054d": "S",  # Ս
    "\u057e": "v",  # վ
    "\u054e": "V",  # Վ
    "\u057f": "t",  # տ
    "\u054f": "T",  # Տ
    "\u0580": "r",  # ր
    "\u0550": "R",  # Ր
    "\u0581": "c",  # ց
    "\u0551": "C",  # Ց
    "\u0578\u0582": "u",  # ու
    "\u0548\u0552": "U",  # ՈՒ
    "\u0548\u0582": "U",  # Ու
    "\u0583": "p",  # փ
    "\u0553": "P",  # Փ
    "\u0584": "q",  # ք
    "\u0554": "Q",  # Ք
    "\u0585": "o",  # օ
    "\u0555": "O",  # Օ
    "\u0586": "f",  # ֆ
    "\u0556": "F",  # Ֆ
    "\u0587": "yev",  # և
    # Georgian
    "\u10d0": "a",  # ა
    "\u10d1": "b",  # ბ
    "\u10d2": "g",  # გ
    "\u10d3": "d",  # დ
    "\u10d4": "e",  # ე
    "\u10d5": "v",  # ვ
    "\u10d6": "z",  # ზ
    "\u10d7": "t",  # თ
    "\u10d8": "i",  # ი
    "\u10d9": "k",  # კ
    "\u10da": "l",  # ლ
    "\u10db": "m",  # მ
    "\u10dc": "n",  # ნ
    "\u10dd": "o",  # ო
    "\u10de": "p",  # პ
    "\u10df": "zh",  # ჟ
    "\u10e0": "r",  # რ
    "\u10e1": "s",  # ს
    "\u10e2": "t",  # ტ
    "\u10e3": "u",  # უ
    "\u10e4": "ph",  # ფ
    "\u10e5": "q",  # ქ
    "\u10e6": "gh",  # ღ
    "\u10e7": "k",  # ყ
    "\u10e8": "sh",  # შ
    "\u10e9": "ch",  # ჩ
    "\u10ea": "ts",  # ც
    "\u10eb": "dz",  # ძ
    "\u10ec": "ts",  # წ
    "\u10ed": "tch",  # ჭ
    "\u10ee": "kh",  # ხ
    "\u10ef": "j",  # ჯ
    "\u10f0": "h",  # ჰ
    # Czech
    "\u010d": "c",  # č
    "\u010f": "d",  # ď
    "\u011b": "e",  # ě
    "\u0148": "n",  # ň
    "\u0159": "r",  # ř
    "\u0161": "s",  # š
    "\u0165": "t",  # ť
    "\u016f": "u",  # ů
    "\u017e": "z",  # ž
    "\u010c": "C",  # Č
    "\u010e": "D",  # Ď
    "\u011a": "E",  # Ě
    "\u0147": "N",  # Ň
    "\u0158": "R",  # Ř
    "\u0160": "S",  # Š
    "\u0164": "T",  # Ť
    "\u016e": "U",  # Ů
    "\u017d": "Z",  # Ž
    # Dhivehi
    "\u0780": "h",  # ހ
    "\u0781": "sh",  # ށ
    "\u0782": "n",  # ނ
    "\u0783": "r",  # ރ
    "\u0784": "b",  # ބ
    "\u0785": "lh",  # ޅ
    "\u0786": "k",  # ކ
    "\u0787": "a",  # އ
    "\u0788": "v",  # ވ
    "\u0789": "m",  # މ
    "\u078a": "f",  # ފ
    "\u078b": "dh",  # ދ
    "\u078c": "th",  # ތ
    "\u078d": "l",  # ލ
    "\u078e": "g",  # ގ
    "\u078f": "gn",  # ޏ
    "\u0790": "s",  # ސ
    "\u0791": "d",  # ޑ
    "\u0792": "z",  # ޒ
    "\u0793": "t",  # ޓ
    "\u0794": "y",  # ޔ
    "\u0795": "p",  # ޕ
    "\u0796": "j",  # ޖ
    "\u0797": "ch",  # ޗ
    "\u0798": "tt",  # ޘ
    "\u0799": "hh",  # ޙ
    "\u079a": "kh",  # ޚ
    "\u079b": "th",  # ޛ
    "\u079c": "z",  # ޜ
    "\u079d": "sh",  # ޝ
    "\u079e": "s",  # ޞ
    "\u079f": "d",  # ޟ
    "\u07a0": "t",  # ޠ
    "\u07a1": "z",  # ޡ
    "\u07a2": "a",  # ޢ
    "\u07a3": "gh",  # ޣ
    "\u07a4": "q",  # ޤ
    "\u07a5": "w",  # ޥ
    "ަ": "a",  # ަ
    "ާ": "aa",  # ާ
    "ި": "i",  # ި
    "ީ": "ee",  # ީ
    "ު": "u",  # ު
    "ޫ": "oo",  # ޫ
    "ެ": "e",  # ެ
    "ޭ": "ey",  # ޭ
    "ޮ": "o",  # ޮ
    "ޯ": "oa",  # ޯ
    "ް": "",  # ް
    # Greek
    "\u03b1": "a",  # α
    "\u03b2": "v",  # β
    "\u03b3": "g",  # γ
    "\u03b4": "d",  # δ
    "\u03b5": "e",  # ε
    "\u03b6": "z",  # ζ
    "\u03b7": "i",  # η
    "\u03b8": "th",  # θ
    "\u03b9": "i",  # ι
    "\u03ba": "k",  # κ
    "\u03bb": "l",  # λ
    "\u03bc": "m",  # μ
    "\u03bd": "n",  # ν
    "\u03be": "ks",  # ξ
    "\u03bf": "o",  # ο
    "\u03c0": "p",  # π
    "\u03c1": "r",  # ρ
    "\u03c3": "s",  # σ
    "\u03c4": "t",  # τ
    "\u03c5": "y",  # υ
    "\u03c6": "f",  # φ
    "\u03c7": "x",  # χ
    "\u03c8": "ps",  # ψ
    "\u03c9": "o",  # ω
    "\u03ac": "a",  # ά
    "\u03ad": "e",  # έ
    "\u03af": "i",  # ί
    "\u03cc": "o",  # ό
    "\u03cd": "y",  # ύ
    "\u03ae": "i",  # ή
    "\u03ce": "o",  # ώ
    "\u03c2": "s",  # ς
    "\u03ca": "i",  # ϊ
    "\u03b0": "y",  # ΰ
    "\u03cb": "y",  # ϋ
    "\u0390": "i",  # ΐ
    "\u0391": "A",  # Α
    "\u0392": "B",  # Β
    "\u0393": "G",  # Γ
    "\u0394": "D",  # Δ
    "\u0395": "E",  # Ε
    "\u0396": "Z",  # Ζ
    "\u0397": "I",  # Η
    "\u0398": "TH",  # Θ
    "\u0399": "I",  # Ι
    "\u039a": "K",  # Κ
    "\u039b": "L",  # Λ
    "\u039c": "M",  # Μ
    "\u039d": "N",  # Ν
    "\u039e": "KS",  # Ξ
    "\u039f": "O",  # Ο
    "\u03a0": "P",  # Π
    "\u03a1": "R",  # Ρ
    "\u03a3": "S",  # Σ
    "\u03a4": "T",  # Τ
    "\u03a5": "Y",  # Υ
    "\u03a6": "F",  # Φ
    "\u03a7": "X",  # Χ
    "\u03a8": "PS",  # Ψ
    "\u03a9": "O",  # Ω
    "\u0386": "A",  # Ά
    "\u0388": "E",  # Έ
    "\u038a": "I",  # Ί
    "\u038c": "O",  # Ό
    "\u038e": "Y",  # Ύ
    "\u0389": "I",  # Ή
    "\u038f": "O",  # Ώ
    "\u03aa": "I",  # Ϊ
    "\u03ab": "Y",  # Ϋ
    # Latvian
    "\u0101": "a",  # ā
    "\u0113": "e",  # ē
    "\u0123": "g",  # ģ
    "\u012b": "i",  # ī
    "\u0137": "k",  # ķ
    "\u013c": "l",  # ļ
    "\u0146": "n",  # ņ
    "\u016b": "u",  # ū
    "\u0100": "A",  # Ā
    "\u0112": "E",  # Ē
    "\u0122": "G",  # Ģ
    "\u012a": "I",  # Ī
    "\u0136": "K",  # Ķ
    "\u013b": "L",  # Ļ
    "\u0145": "N",  # Ņ
    "\u016a": "U",  # Ū
    # Lithuanian
    "\u0105": "a",  # ą
    "\u0119": "e",  # ę
    "\u0117": "e",  # ė
    "\u012f": "i",  # į
    "\u0173": "u",  # ų
    "\u0104": "A",  # Ą
    "\u0118": "E",  # Ę
    "\u0116": "E",  # Ė
    "\u012e": "I",  # Į
    "\u0172": "U",  # Ų
    # Macedonian
    "\u040c": "Kj",  # Ќ
    "\u045c": "kj",  # ќ
    "\u0409": "Lj",  # Љ
    "\u0459": "lj",  # љ
    "\u040a": "Nj",  # Њ
    "\u045a": "nj",  # њ
    "\u0422\u0441": "Ts",  # Тс
    "\u0442\u0441": "ts",  # тс
    # Polish
    "\u0107": "c",  # ć
    "\u0142": "l",  # ł
    "\u0144": "n",  # ń
    "\u015b": "s",  # ś
    "\u017a": "z",  # ź
    "\u017c": "z",  # ż
    "\u0106": "C",  # Ć
    "\u0141": "L",  # Ł
    "\u0143": "N",  # Ń
    "\u015a": "S",  # Ś
    "\u0179": "Z",  # Ź
    "\u017b": "Z",  # Ż
    # Ukrainian
    "\u0404": "Ye",  # Є
    "\u0406": "I",  # І
    "\u0407": "Yi",  # Ї
    "\u0490": "G",  # Ґ
    "\u0454": "ye",  # є
    "\u0456": "i",  # і
    "\u0457": "yi",  # ї
    "\u0491": "g",  # ґ
    # Dutch
    "\u0132": "IJ",  # Ĳ
    "\u0133": "ij",  # ĳ
    # Currencies
    "\u00a2": "c",  # ¢
    "\u00a5": "Y",  # ¥
    "\u07ff": "b",  # ߿
    "\u09f3": "t",  # ৳
    "\u0af1": "Bo",  # ૱
    "\u0e3f": "B",  # ฿
    "\u20a0": "CE",  # ₠
    "\u20a1": "C",  # ₡
    "\u20a2": "Cr",  # ₢
    "\u20a3": "F",  # ₣
    "\u20a5": "m",  # ₥
    "\u20a6": "N",  # ₦
    "\u20a7": "Pt",  # ₧
    "\u20a8": "Rs",  # ₨
    "\u20a9": "W",  # ₩
    "\u20ab": "s",  # ₫
    "\u20ac": "E",  # €
    "\u20ad": "K",  # ₭
    "\u20ae": "T",  # ₮
    "\u20af": "Dp",  # ₯
    "\u20b0": "S",  # ₰
    "\u20b1": "P",  # ₱
    "\u20b2": "G",  # ₲
    "\u20b3": "A",  # ₳
    "\u20b4": "S",  # ₴
    "\u20b5": "C",  # ₵
    "\u20b6": "tt",  # ₶
    "\u20b7": "S",  # ₷
    "\u20b8": "T",  # ₸
    "\u20b9": "R",  # ₹
    "\u20ba": "L",  # ₺
    "\u20bd": "P",  # ₽
    "\u20bf": "B",  # ₿
    "\ufe69": "$",  # ﹩
    "\uffe0": "c",  # ￠
    "\uffe5": "Y",  # ￥
    "\uffe6": "W",  # ￦
    # Latin
    "\U0001d400": "A",  # 𝐀
    "\U0001d401": "B",  # 𝐁
    "\U0001d402": "C",  # 𝐂
    "\U0001d403": "D",  # 𝐃
    "\U0001d404": "E",  # 𝐄
    "\U0001d405": "F",  # 𝐅
    "\U0001d406": "G",  # 𝐆
    "\U0001d407": "H",  # 𝐇
    "\U0001d408": "I",  # 𝐈
    "\U0001d409": "J",  # 𝐉
    "\U0001d40a": "K",  # 𝐊
    "\U0001d40b": "L",  # 𝐋
    "\U0001d40c": "M",  # 𝐌
    "\U0001d40d": "N",  # 𝐍
    "\U0001d40e": "O",  # 𝐎
    "\U0001d40f": "P",  # 𝐏
    "\U0001d410": "Q",  # 𝐐
    "\U0001d411": "R",  # 𝐑
    "\U0001d412": "S",  # 𝐒
    "\U0001d413": "T",  # 𝐓
    "\U0001d414": "U",  # 𝐔
    "\U0001d415": "V",  # 𝐕
    "\U0001d416": "W",  # 𝐖
    "\U0001d417": "X",  # 𝐗
    "\U0001d418": "Y",  # 𝐘
    "\U0001d419": "Z",  # 𝐙
    "\U0001d41a": "a",  # 𝐚
    "\U0001d41b": "b",  # 𝐛
    "\U0001d41c": "c",  # 𝐜
    "\U0001d41d": "d",  # 𝐝
    "\U0001d41e": "e",  # 𝐞
    "\U0001d41f": "f",  # 𝐟
    "\U0001d420": "g",  # 𝐠
    "\U0001d421": "h",  # 𝐡
    "\U0001d422": "i",  # 𝐢
    "\U0001d423": "j",  # 𝐣
    "\U0001d424": "k",  # 𝐤
    "\U0001d425": "l",  # 𝐥
    "\U0001d426": "m",  # 𝐦
    "\U0001d427": "n",  # 𝐧
    "\U0001d428": "o",  # 𝐨
    "\U0001d429": "p",  # 𝐩
    "\U0001d42a": "q",  # 𝐪
    "\U0001d42b": "r",  # 𝐫
    "\U0001d42c": "s",  # 𝐬
    "\U0001d42d": "t",  # 𝐭
    "\U0001d42e": "u",  # 𝐮
    "\U0001d42f": "v",  # 𝐯
    "\U0001d430": "w",  # 𝐰
    "\U0001d431": "x",  # 𝐱
    "\U0001d432": "y",  # 𝐲
    "\U0001d433": "z",  # 𝐳
    "\U0001d434": "A",  # 𝐴
    "\U0001d435": "B",  # 𝐵
    "\U0001d436": "C",  # 𝐶
    "\U0001d437": "D",  # 𝐷
    "\U0001d438": "E",  # 𝐸
    "\U0001d439": "F",  # 𝐹
    "\U0001d43a": "G",  # 𝐺
    "\U0001d43b": "H",  # 𝐻
    "\U0001d43c": "I",  # 𝐼
    "\U0001d43d": "J",  # 𝐽
    "\U0001d43e": "K",  # 𝐾
    "\U0001d43f": "L",  # 𝐿
    "\U0001d440": "M",  # 𝑀
    "\U0001d441": "N",  # 𝑁
    "\U0001d442": "O",  # 𝑂
    "\U0001d443": "P",  # 𝑃
    "\U0001d444": "Q",  # 𝑄
    "\U0001d445": "R",  # 𝑅
    "\U0001d446": "S",  # 𝑆
    "\U0001d447": "T",  # 𝑇
    "\U0001d448": "U",  # 𝑈
    "\U0001d449": "V",  # 𝑉
    "\U0001d44a": "W",  # 𝑊
    "\U0001d44b": "X",  # 𝑋
    "\U0001d44c": "Y",  # 𝑌
    "\U0001d44d": "Z",  # 𝑍
    "\U0001d44e": "a",  # 𝑎
    "\U0001d44f": "b",  # 𝑏
    "\U0001d450": "c",  # 𝑐
    "\U0001d451": "d",  # 𝑑
    "\U0001d452": "e",  # 𝑒
    "\U0001d453": "f",  # 𝑓
    "\U0001d454": "g",  # 𝑔
    "\U0001d456": "i",  # 𝑖
    "\U0001d457": "j",  # 𝑗
    "\U0001d458": "k",  # 𝑘
    "\U0001d459": "l",  # 𝑙
    "\U0001d45a": "m",  # 𝑚
    "\U0001d45b": "n",  # 𝑛
    "\U0001d45c": "o",  # 𝑜
    "\U0001d45d": "p",  # 𝑝
    "\U0001d45e": "q",  # 𝑞
    "\U0001d45f": "r",  # 𝑟
    "\U0001d460": "s",  # 𝑠
    "\U0001d461": "t",  # 𝑡
    "\U0001d462": "u",  # 𝑢
    "\U0001d463": "v",  # 𝑣
    "\U0001d464": "w",  # 𝑤
    "\U0001d465": "x",  # 𝑥
    "\U0001d466": "y",  # 𝑦
    "\U0001d467": "z",  # 𝑧
    "\U0001d468": "A",  # 𝑨
    "\U0001d469": "B",  # 𝑩
    "\U0001d46a": "C",  # 𝑪
    "\U0001d46b": "D",  # 𝑫
    "\U0001d46c": "E",  # 𝑬
    "\U0001d46d": "F",  # 𝑭
    "\U0001d46e": "G",  # 𝑮
    "\U0001d46f": "H",  # 𝑯
    "\U0001d470": "I",  # 𝑰
    "\U0001d471": "J",  # 𝑱
    "\U0001d472": "K",  # 𝑲
    "\U0001d473": "L",  # 𝑳
    "\U0001d474": "M",  # 𝑴
    "\U0001d475": "N",  # 𝑵
    "\U0001d476": "O",  # 𝑶
    "\U0001d477": "P",  # 𝑷
    "\U0001d478": "Q",  # 𝑸
    "\U0001d479": "R",  # 𝑹
    "\U0001d47a": "S",  # 𝑺
    "\U0001d47b": "T",  # 𝑻
    "\U0001d47c": "U",  # 𝑼
    "\U0001d47d": "V",  # 𝑽
    "\U0001d47e": "W",  # 𝑾
    "\U0001d47f": "X",  # 𝑿
    "\U0001d480": "Y",  # 𝒀
    "\U0001d481": "Z",  # 𝒁
    "\U0001d482": "a",  # 𝒂
    "\U0001d483": "b",  # 𝒃
    "\U0001d484": "c",  # 𝒄
    "\U0001d485": "d",  # 𝒅
    "\U0001d486": "e",  # 𝒆
    "\U0001d487": "f",  # 𝒇
    "\U0001d488": "g",  # 𝒈
    "\U0001d489": "h",  # 𝒉
    "\U0001d48a": "i",  # 𝒊
    "\U0001d48b": "j",  # 𝒋
    "\U0001d48c": "k",  # 𝒌
    "\U0001d48d": "l",  # 𝒍
    "\U0001d48e": "m",  # 𝒎
    "\U0001d48f": "n",  # 𝒏
    "\U0001d490": "o",  # 𝒐
    "\U0001d491": "p",  # 𝒑
    "\U0001d492": "q",  # 𝒒
    "\U0001d493": "r",  # 𝒓
    "\U0001d494": "s",  # 𝒔
    "\U0001d495": "t",  # 𝒕
    "\U0001d496": "u",  # 𝒖
    "\U0001d497": "v",  # 𝒗
    "\U0001d498": "w",  # 𝒘
    "\U0001d499": "x",  # 𝒙
    "\U0001d49a": "y",  # 𝒚
    "\U0001d49b": "z",  # 𝒛
    "\U0001d49c": "A",  # 𝒜
    "\U0001d49e": "C",  # 𝒞
    "\U0001d49f": "D",  # 𝒟
    "\U0001d4a2": "g",  # 𝒢
    "\U0001d4a5": "J",  # 𝒥
    "\U0001d4a6": "K",  # 𝒦
    "\U0001d4a9": "N",  # 𝒩
    "\U0001d4aa": "O",  # 𝒪
    "\U0001d4ab": "P",  # 𝒫
    "\U0001d4ac": "Q",  # 𝒬
    "\U0001d4ae": "S",  # 𝒮
    "\U0001d4af": "T",  # 𝒯
    "\U0001d4b0": "U",  # 𝒰
    "\U0001d4b1": "V",  # 𝒱
    "\U0001d4b2": "W",  # 𝒲
    "\U0001d4b3": "X",  # 𝒳
    "\U0001d4b4": "Y",  # 𝒴
    "\U0001d4b5": "Z",  # 𝒵
    "\U0001d4b6": "a",  # 𝒶
    "\U0001d4b7": "b",  # 𝒷
    "\U0001d4b8": "c",  # 𝒸
    "\U0001d4b9": "d",  # 𝒹
    "\U0001d4bb": "f",  # 𝒻
    "\U0001d4bd": "h",  # 𝒽
    "\U0001d4be": "i",  # 𝒾
    "\U0001d4bf": "j",  # 𝒿
    "\U0001d4c0": "h",  # 𝓀
    "\U0001d4c1": "l",  # 𝓁
    "\U0001d4c2": "m",  # 𝓂
    "\U0001d4c3": "n",  # 𝓃
    "\U0001d4c5": "p",  # 𝓅
    "\U0001d4c6": "q",  # 𝓆
    "\U0001d4c7": "r",  # 𝓇
    "\U0001d4c8": "s",  # 𝓈
    "\U0001d4c9": "t",  # 𝓉
    "\U0001d4ca": "u",  # 𝓊
    "\U0001d4cb": "v",  # 𝓋
    "\U0001d4cc": "w",  # 𝓌
    "\U0001d4cd": "x",  # 𝓍
    "\U0001d4ce": "y",  # 𝓎
    "\U0001d4cf": "z",  # 𝓏
    "\U0001d4d0": "A",  # 𝓐
    "\U0001d4d1": "B",  # 𝓑
    "\U0001d4d2": "C",  # 𝓒
    "\U0001d4d3": "D",  # 𝓓
    "\U0001d4d4": "E",  # 𝓔
    "\U0001d4d5": "F",  # 𝓕
    "\U0001d4d6": "G",  # 𝓖
    "\U0001d4d7": "H",  # 𝓗
    "\U0001d4d8": "I",  # 𝓘
    "\U0001d4d9": "J",  # 𝓙
    "\U0001d4da": "K",  # 𝓚
    "\U0001d4db": "L",  # 𝓛
    "\U0001d4dc": "M",  # 𝓜
    "\U0001d4dd": "N",  # 𝓝
    "\U0001d4de": "O",  # 𝓞
    "\U0001d4df": "P",  # 𝓟
    "\U0001d4e0": "Q",  # 𝓠
    "\U0001d4e1": "R",  # 𝓡
    "\U0001d4e2": "S",  # 𝓢
    "\U0001d4e3": "T",  # 𝓣
    "\U0001d4e4": "U",  # 𝓤
    "\U0001d4e5": "V",  # 𝓥
    "\U0001d4e6": "W",  # 𝓦
    "\U0001d4e7": "X",  # 𝓧
    "\U0001d4e8": "Y",  # 𝓨
    "\U0001d4e9": "Z",  # 𝓩
    "\U0001d4ea": "a",  # 𝓪
    "\U0001d4eb": "b",  # 𝓫
    "\U0001d4ec": "c",  # 𝓬
    "\U0001d4ed": "d",  # 𝓭
    "\U0001d4ee": "e",  # 𝓮
    "\U0001d4ef": "f",  # 𝓯
    "\U0001d4f0": "g",  # 𝓰
    "\U0001d4f1": "h",  # 𝓱
    "\U0001d4f2": "i",  # 𝓲
    "\U0001d4f3": "j",  # 𝓳
    "\U0001d4f4": "k",  # 𝓴
    "\U0001d4f5": "l",  # 𝓵
    "\U0001d4f6": "m",  # 𝓶
    "\U0001d4f7": "n",  # 𝓷
    "\U0001d4f8": "o",  # 𝓸
    "\U0001d4f9": "p",  # 𝓹
    "\U0001d4fa": "q",  # 𝓺
    "\U0001d4fb": "r",  # 𝓻
    "\U0001d4fc": "s",  # 𝓼
    "\U0001d4fd": "t",  # 𝓽
    "\U0001d4fe": "u",  # 𝓾
    "\U0001d4ff": "v",  # 𝓿
    "\U0001d500": "w",  # 𝔀
    "\U0001d501": "x",  # 𝔁
    "\U0001d502": "y",  # 𝔂
    "\U0001d503": "z",  # 𝔃
    "\U0001d504": "A",  # 𝔄
    "\U0001d505": "B",  # 𝔅
    "\U0001d507": "D",  # 𝔇
    "\U0001d508": "E",  # 𝔈
    "\U0001d509": "F",  # 𝔉
    "\U0001d50a": "G",  # 𝔊
    "\U0001d50d": "J",  # 𝔍
    "\U0001d50e": "K",  # 𝔎
    "\U0001d50f": "L",  # 𝔏
    "\U0001d510": "M",  # 𝔐
    "\U0001d511": "N",  # 𝔑
    "\U0001d512": "O",  # 𝔒
    "\U0001d513": "P",  # 𝔓
    "\U0001d514": "Q",  # 𝔔
    "\U0001d516": "S",  # 𝔖
    "\U0001d517": "T",  # 𝔗
    "\U0001d518": "U",  # 𝔘
    "\U0001d519": "V",  # 𝔙
    "\U0001d51a": "W",  # 𝔚
    "\U0001d51b": "X",  # 𝔛
    "\U0001d51c": "Y",  # 𝔜
    "\U0001d51e": "a",  # 𝔞
    "\U0001d51f": "b",  # 𝔟
    "\U0001d520": "c",  # 𝔠
    "\U0001d521": "d",  # 𝔡
    "\U0001d522": "e",  # 𝔢
    "\U0001d523": "f",  # 𝔣
    "\U0001d524": "g",  # 𝔤
    "\U0001d525": "h",  # 𝔥
    "\U0001d526": "i",  # 𝔦
    "\U0001d527": "j",  # 𝔧
    "\U0001d528": "k",  # 𝔨
    "\U0001d529": "l",  # 𝔩
    "\U0001d52a": "m",  # 𝔪
    "\U0001d52b": "n",  # 𝔫
    "\U0001d52c": "o",  # 𝔬
    "\U0001d52d": "p",  # 𝔭
    "\U0001d52e": "q",  # 𝔮
    "\U0001d52f": "r",  # 𝔯
    "\U0001d530": "s",  # 𝔰
    "\U0001d531": "t",  # 𝔱
    "\U0001d532": "u",  # 𝔲
    "\U0001d533": "v",  # 𝔳
    "\U0001d534": "w",  # 𝔴
    "\U0001d535": "x",  # 𝔵
    "\U0001d536": "y",  # 𝔶
    "\U0001d537": "z",  # 𝔷
    "\U0001d538": "A",  # 𝔸
    "\U0001d539": "B",  # 𝔹
    "\U0001d53b": "D",  # 𝔻
    "\U0001d53c": "E",  # 𝔼
    "\U0001d53d": "F",  # 𝔽
    "\U0001d53e": "G",  # 𝔾
    "\U0001d540": "I",  # 𝕀
    "\U0001d541": "J",  # 𝕁
    "\U0001d542": "K",  # 𝕂
    "\U0001d543": "L",  # 𝕃
    "\U0001d544": "M",  # 𝕄
    "\U0001d546": "N",  # 𝕆
    "\U0001d54a": "S",  # 𝕊
    "\U0001d54b": "T",  # 𝕋
    "\U0001d54c": "U",  # 𝕌
    "\U0001d54d": "V",  # 𝕍
    "\U0001d54e": "W",  # 𝕎
    "\U0001d54f": "X",  # 𝕏
    "\U0001d550": "Y",  # 𝕐
    "\U0001d552": "a",  # 𝕒
    "\U0001d553": "b",  # 𝕓
    "\U0001d554": "c",  # 𝕔
    "\U0001d555": "d",  # 𝕕
    "\U0001d556": "e",  # 𝕖
    "\U0001d557": "f",  # 𝕗
    "\U0001d558": "g",  # 𝕘
    "\U0001d559": "h",  # 𝕙
    "\U0001d55a": "i",  # 𝕚
    "\U0001d55b": "j",  # 𝕛
    "\U0001d55c": "k",  # 𝕜
    "\U0001d55d": "l",  # 𝕝
    "\U0001d55e": "m",  # 𝕞
    "\U0001d55f": "n",  # 𝕟
    "\U0001d560": "o",  # 𝕠
    "\U0001d561": "p",  # 𝕡
    "\U0001d562": "q",  # 𝕢
    "\U0001d563": "r",  # 𝕣
    "\U0001d564": "s",  # 𝕤
    "\U0001d565": "t",  # 𝕥
    "\U0001d566": "u",  # 𝕦
    "\U0001d567": "v",  # 𝕧
    "\U0001d568": "w",  # 𝕨
    "\U0001d569": "x",  # 𝕩
    "\U0001d56a": "y",  # 𝕪
    "\U0001d56b": "z",  # 𝕫
    "\U0001d56c": "A",  # 𝕬
    "\U0001d56d": "B",  # 𝕭
    "\U0001d56e": "C",  # 𝕮
    "\U0001d56f": "D",  # 𝕯
    "\U0001d570": "E",  # 𝕰
    "\U0001d571": "F",  # 𝕱
    "\U0001d572": "G",  # 𝕲
    "\U0001d573": "H",  # 𝕳
    "\U0001d574": "I",  # 𝕴
    "\U0001d575": "J",  # 𝕵
    "\U0001d576": "K",  # 𝕶
    "\U0001d577": "L",  # 𝕷
    "\U0001d578": "M",  # 𝕸
    "\U0001d579": "N",  # 𝕹
    "\U0001d57a": "O",  # 𝕺
    "\U0001d57b": "P",  # 𝕻
    "\U0001d57c": "Q",  # 𝕼
    "\U0001d57d": "R",  # 𝕽
    "\U0001d57e": "S",  # 𝕾
    "\U0001d57f": "T",  # 𝕿
    "\U0001d580": "U",  # 𝖀
    "\U0001d581": "V",  # 𝖁
    "\U0001d582": "W",  # 𝖂
    "\U0001d583": "X",  # 𝖃
    "\U0001d584": "Y",  # 𝖄
    "\U0001d585": "Z",  # 𝖅
    "\U0001d586": "a",  # 𝖆
    "\U0001d587": "b",  # 𝖇
    "\U0001d588": "c",  # 𝖈
    "\U0001d589": "d",  # 𝖉
    "\U0001d58a": "e",  # 𝖊
    "\U0001d58b": "f",  # 𝖋
    "\U0001d58c": "g",  # 𝖌
    "\U0001d58d": "h",  # 𝖍
    "\U0001d58e": "i",  # 𝖎
    "\U0001d58f": "j",  # 𝖏
    "\U0001d590": "k",  # 𝖐
    "\U0001d591": "l",  # 𝖑
    "\U0001d592": "m",  # 𝖒
    "\U0001d593": "n",  # 𝖓
    "\U0001d594": "o",  # 𝖔
    "\U0001d595": "p",  # 𝖕
    "\U0001d596": "q",  # 𝖖
    "\U0001d597": "r",  # 𝖗
    "\U0001d598": "s",  # 𝖘
    "\U0001d599": "t",  # 𝖙
    "\U0001d59a": "u",  # 𝖚
    "\U0001d59b": "v",  # 𝖛
    "\U0001d59c": "w",  # 𝖜
    "\U0001d59d": "x",  # 𝖝
    "\U0001d59e": "y",  # 𝖞
    "\U0001d59f": "z",  # 𝖟
    "\U0001d5a0": "A",  # 𝖠
    "\U0001d5a1": "B",  # 𝖡
    "\U0001d5a2": "C",  # 𝖢
    "\U0001d5a3": "D",  # 𝖣
    "\U0001d5a4": "E",  # 𝖤
    "\U0001d5a5": "F",  # 𝖥
    "\U0001d5a6": "G",  # 𝖦
    "\U0001d5a7": "H",  # 𝖧
    "\U0001d5a8": "I",  # 𝖨
    "\U0001d5a9": "J",  # 𝖩
    "\U0001d5aa": "K",  # 𝖪
    "\U0001d5ab": "L",  # 𝖫
    "\U0001d5ac": "M",  # 𝖬
    "\U0001d5ad": "N",  # 𝖭
    "\U0001d5ae": "O",  # 𝖮
    "\U0001d5af": "P",  # 𝖯
    "\U0001d5b0": "Q",  # 𝖰
    "\U0001d5b1": "R",  # 𝖱
    "\U0001d5b2": "S",  # 𝖲
    "\U0001d5b3": "T",  # 𝖳
    "\U0001d5b4": "U",  # 𝖴
    "\U0001d5b5": "V",  # 𝖵
    "\U0001d5b6": "W",  # 𝖶
    "\U0001d5b7": "X",  # 𝖷
    "\U0001d5b8": "Y",  # 𝖸
    "\U0001d5b9": "Z",  # 𝖹
    "\U0001d5ba": "a",  # 𝖺
    "\U0001d5bb": "b",  # 𝖻
    "\U0001d5bc": "c",  # 𝖼
    "\U0001d5bd": "d",  # 𝖽
    "\U0001d5be": "e",  # 𝖾
    "\U0001d5bf": "f",  # 𝖿
    "\U0001d5c0": "g",  # 𝗀
    "\U0001d5c1": "h",  # 𝗁
    "\U0001d5c2": "i",  # 𝗂
    "\U0001d5c3": "j",  # 𝗃
    "\U0001d5c4": "k",  # 𝗄
    "\U0001d5c5": "l",  # 𝗅
    "\U0001d5c6": "m",  # 𝗆
    "\U0001d5c7": "n",  # 𝗇
    "\U0001d5c8": "o",  # 𝗈
    "\U0001d5c9": "p",  # 𝗉
    "\U0001d5ca": "q",  # 𝗊
    "\U0001d5cb": "r",  # 𝗋
    "\U0001d5cc": "s",  # 𝗌
    "\U0001d5cd": "t",  # 𝗍
    "\U0001d5ce": "u",  # 𝗎
    "\U0001d5cf": "v",  # 𝗏
    "\U0001d5d0": "w",  # 𝗐
    "\U0001d5d1": "x",  # 𝗑
    "\U0001d5d2": "y",  # 𝗒
    "\U0001d5d3": "z",  # 𝗓
    "\U0001d5d4": "A",  # 𝗔
    "\U0001d5d5": "B",  # 𝗕
    "\U0001d5d6": "C",  # 𝗖
    "\U0001d5d7": "D",  # 𝗗
    "\U0001d5d8": "E",  # 𝗘
    "\U0001d5d9": "F",  # 𝗙
    "\U0001d5da": "G",  # 𝗚
    "\U0001d5db": "H",  # 𝗛
    "\U0001d5dc": "I",  # 𝗜
    "\U0001d5dd": "J",  # 𝗝
    "\U0001d5de": "K",  # 𝗞
    "\U0001d5df": "L",  # 𝗟
    "\U0001d5e0": "M",  # 𝗠
    "\U0001d5e1": "N",  # 𝗡
    "\U0001d5e2": "O",  # 𝗢
    "\U0001d5e3": "P",  # 𝗣
    "\U0001d5e4": "Q",  # 𝗤
    "\U0001d5e5": "R",  # 𝗥
    "\U0001d5e6": "S",  # 𝗦
    "\U0001d5e7": "T",  # 𝗧
    "\U0001d5e8": "U",  # 𝗨
    "\U0001d5e9": "V",  # 𝗩
    "\U0001d5ea": "W",  # 𝗪
    "\U0001d5eb": "X",  # 𝗫
    "\U0001d5ec": "Y",  # 𝗬
    "\U0001d5ed": "Z",  # 𝗭
    "\U0001d5ee": "a",  # 𝗮
    "\U0001d5ef": "b",  # 𝗯
    "\U0001d5f0": "c",  # 𝗰
    "\U0001d5f1": "d",  # 𝗱
    "\U0001d5f2": "e",  # 𝗲
    "\U0001d5f3": "f",  # 𝗳
    "\U0001d5f4": "g",  # 𝗴
    "\U0001d5f5": "h",  # 𝗵
    "\U0001d5f6": "i",  # 𝗶
    "\U0001d5f7": "j",  # 𝗷
    "\U0001d5f8": "k",  # 𝗸
    "\U0001d5f9": "l",  # 𝗹
    "\U0001d5fa": "m",  # 𝗺
    "\U0001d5fb": "n",  # 𝗻
    "\U0001d5fc": "o",  # 𝗼
    "\U0001d5fd": "p",  # 𝗽
    "\U0001d5fe": "q",  # 𝗾
    "\U0001d5ff": "r",  # 𝗿
    "\U0001d600": "s",  # 𝘀
    "\U0001d601": "t",  # 𝘁
    "\U0001d602": "u",  # 𝘂
    "\U0001d603": "v",  # 𝘃
    "\U0001d604": "w",  # 𝘄
    "\U0001d605": "x",  # 𝘅
    "\U0001d606": "y",  # 𝘆
    "\U0001d607": "z",  # 𝘇
    "\U0001d608": "A",  # 𝘈
    "\U0001d609": "B",  # 𝘉
    "\U0001d60a": "C",  # 𝘊
    "\U0001d60b": "D",  # 𝘋
    "\U0001d60c": "E",  # 𝘌
    "\U0001d60d": "F",  # 𝘍
    "\U0001d60e": "G",  # 𝘎
    "\U0001d60f": "H",  # 𝘏
    "\U0001d610": "I",  # 𝘐
    "\U0001d611": "J",  # 𝘑
    "\U0001d612": "K",  # 𝘒
    "\U0001d613": "L",  # 𝘓
    "\U0001d614": "M",  # 𝘔
    "\U0001d615": "N",  # 𝘕
    "\U0001d616": "O",  # 𝘖
    "\U0001d617": "P",  # 𝘗
    "\U0001d618": "Q",  # 𝘘
    "\U0001d619": "R",  # 𝘙
    "\U0001d61a": "S",  # 𝘚
    "\U0001d61b": "T",  # 𝘛
    "\U0001d61c": "U",  # 𝘜
    "\U0001d61d": "V",  # 𝘝
    "\U0001d61e": "W",  # 𝘞
    "\U0001d61f": "X",  # 𝘟
    "\U0001d620": "Y",  # 𝘠
    "\U0001d621": "Z",  # 𝘡
    "\U0001d622": "a",  # 𝘢
    "\U0001d623": "b",  # 𝘣
    "\U0001d624": "c",  # 𝘤
    "\U0001d625": "d",  # 𝘥
    "\U0001d626": "e",  # 𝘦
    "\U0001d627": "f",  # 𝘧
    "\U0001d628": "g",  # 𝘨
    "\U0001d629": "h",  # 𝘩
    "\U0001d62a": "i",  # 𝘪
    "\U0001d62b": "j",  # 𝘫
    "\U0001d62c": "k",  # 𝘬
    "\U0001d62d": "l",  # 𝘭
    "\U0001d62e": "m",  # 𝘮
    "\U0001d62f": "n",  # 𝘯
    "\U0001d630": "o",  # 𝘰
    "\U0001d631": "p",  # 𝘱
    "\U0001d632": "q",  # 𝘲
    "\U0001d633": "r",  # 𝘳
    "\U0001d634": "s",  # 𝘴
    "\U0001d635": "t",  # 𝘵
    "\U0001d636": "u",  # 𝘶
    "\U0001d637": "v",  # 𝘷
    "\U0001d638": "w",  # 𝘸
    "\U0001d639": "x",  # 𝘹
    "\U0001d63a": "y",  # 𝘺
    "\U0001d63b": "z",  # 𝘻
    "\U0001d63c": "A",  # 𝘼
    "\U0001d63d": "B",  # 𝘽
    "\U0001d63e": "C",  # 𝘾
    "\U0001d63f": "D",  # 𝘿
    "\U0001d640": "E",  # 𝙀
    "\U0001d641": "F",  # 𝙁
    "\U0001d642": "G",  # 𝙂
    "\U0001d643": "H",  # 𝙃
    "\U0001d644": "I",  # 𝙄
    "\U0001d645": "J",  # 𝙅
    "\U0001d646": "K",  # 𝙆
    "\U0001d647": "L",  # 𝙇
    "\U0001d648": "M",  # 𝙈
    "\U0001d649": "N",  # 𝙉
    "\U0001d64a": "O",  # 𝙊
    "\U0001d64b": "P",  # 𝙋
    "\U0001d64c": "Q",  # 𝙌
    "\U0001d64d": "R",  # 𝙍
    "\U0001d64e": "S",  # 𝙎
    "\U0001d64f": "T",  # 𝙏
    "\U0001d650": "U",  # 𝙐
    "\U0001d651": "V",  # 𝙑
    "\U0001d652": "W",  # 𝙒
    "\U0001d653": "X",  # 𝙓
    "\U0001d654": "Y",  # 𝙔
    "\U0001d655": "Z",  # 𝙕
    "\U0001d656": "a",  # 𝙖
    "\U0001d657": "b",  # 𝙗
    "\U0001d658": "c",  # 𝙘
    "\U0001d659": "d",  # 𝙙
    "\U0001d65a": "e",  # 𝙚
    "\U0001d65b": "f",  # 𝙛
    "\U0001d65c": "g",  # 𝙜
    "\U0001d65d": "h",  # 𝙝
    "\U0001d65e": "i",  # 𝙞
    "\U0001d65f": "j",  # 𝙟
    "\U0001d660": "k",  # 𝙠
    "\U0001d661": "l",  # 𝙡
    "\U0001d662": "m",  # 𝙢
    "\U0001d663": "n",  # 𝙣
    "\U0001d664": "o",  # 𝙤
    "\U0001d665": "p",  # 𝙥
    "\U0001d666": "q",  # 𝙦
    "\U0001d667": "r",  # 𝙧
    "\U0001d668": "s",  # 𝙨
    "\U0001d669": "t",  # 𝙩
    "\U0001d66a": "u",  # 𝙪
    "\U0001d66b": "v",  # 𝙫
    "\U0001d66c": "w",  # 𝙬
    "\U0001d66d": "x",  # 𝙭
    "\U0001d66e": "y",  # 𝙮
    "\U0001d66f": "z",  # 𝙯
    "\U0001d670": "A",  # 𝙰
    "\U0001d671": "B",  # 𝙱
    "\U0001d672": "C",  # 𝙲
    "\U0001d673": "D",  # 𝙳
    "\U0001d674": "E",  # 𝙴
    "\U0001d675": "F",  # 𝙵
    "\U0001d676": "G",  # 𝙶
    "\U0001d677": "H",  # 𝙷
    "\U0001d678": "I",  # 𝙸
    "\U0001d679": "J",  # 𝙹
    "\U0001d67a": "K",  # 𝙺
    "\U0001d67b": "L",  # 𝙻
    "\U0001d67c": "M",  # 𝙼
    "\U0001d67d": "N",  # 𝙽
    "\U0001d67e": "O",  # 𝙾
    "\U0001d67f": "P",  # 𝙿
    "\U0001d680": "Q",  # 𝚀
    "\U0001d681": "R",  # 𝚁
    "\U0001d682": "S",  # 𝚂
    "\U0001d683": "T",  # 𝚃
    "\U0001d684": "U",  # 𝚄
    "\U0001d685": "V",  # 𝚅
    "\U0001d686": "W",  # 𝚆
    "\U0001d687": "X",  # 𝚇
    "\U0001d688": "Y",  # 𝚈
    "\U0001d689": "Z",  # 𝚉
    "\U0001d68a": "a",  # 𝚊
    "\U0001d68b": "b",  # 𝚋
    "\U0001d68c": "c",  # 𝚌
    "\U0001d68d": "d",  # 𝚍
    "\U0001d68e": "e",  # 𝚎
    "\U0001d68f": "f",  # 𝚏
    "\U0001d690": "g",  # 𝚐
    "\U0001d691": "h",  # 𝚑
    "\U0001d692": "i",  # 𝚒
    "\U0001d693": "j",  # 𝚓
    "\U0001d694": "k",  # 𝚔
    "\U0001d695": "l",  # 𝚕
    "\U0001d696": "m",  # 𝚖
    "\U0001d697": "n",  # 𝚗
    "\U0001d698": "o",  # 𝚘
    "\U0001d699": "p",  # 𝚙
    "\U0001d69a": "q",  # 𝚚
    "\U0001d69b": "r",  # 𝚛
    "\U0001d69c": "s",  # 𝚜
    "\U0001d69d": "t",  # 𝚝
    "\U0001d69e": "u",  # 𝚞
    "\U0001d69f": "v",  # 𝚟
    "\U0001d6a0": "w",  # 𝚠
    "\U0001d6a1": "x",  # 𝚡
    "\U0001d6a2": "y",  # 𝚢
    "\U0001d6a3": "z",  # 𝚣
    # Dotless letters
    "\U0001d6a4": "l",  # 𝚤
    "\U0001d6a5": "j",  # 𝚥
    # Greek
    "\U0001d6e2": "A",  # 𝛢
    "\U0001d6e3": "B",  # 𝛣
    "\U0001d6e4": "G",  # 𝛤
    "\U0001d6e5": "D",  # 𝛥
    "\U0001d6e6": "E",  # 𝛦
    "\U0001d6e7": "Z",  # 𝛧
    "\U0001d6e8": "I",  # 𝛨
    "\U0001d6e9": "TH",  # 𝛩
    "\U0001d6ea": "I",  # 𝛪
    "\U0001d6eb": "K",  # 𝛫
    "\U0001d6ec": "L",  # 𝛬
    "\U0001d6ed": "M",  # 𝛭
    "\U0001d6ee": "N",  # 𝛮
    "\U0001d6ef": "KS",  # 𝛯
    "\U0001d6f0": "O",  # 𝛰
    "\U0001d6f1": "P",  # 𝛱
    "\U0001d6f2": "R",  # 𝛲
    "\U0001d6f3": "TH",  # 𝛳
    "\U0001d6f4": "S",  # 𝛴
    "\U0001d6f5": "T",  # 𝛵
    "\U0001d6f6": "Y",  # 𝛶
    "\U0001d6f7": "F",  # 𝛷
    "\U0001d6f8": "x",  # 𝛸
    "\U0001d6f9": "PS",  # 𝛹
    "\U0001d6fa": "O",  # 𝛺
    "\U0001d6fb": "D",  # 𝛻
    "\U0001d6fc": "a",  # 𝛼
    "\U0001d6fd": "b",  # 𝛽
    "\U0001d6fe": "g",  # 𝛾
    "\U0001d6ff": "d",  # 𝛿
    "\U0001d700": "e",  # 𝜀
    "\U0001d701": "z",  # 𝜁
    "\U0001d702": "i",  # 𝜂
    "\U0001d703": "th",  # 𝜃
    "\U0001d704": "i",  # 𝜄
    "\U0001d705": "k",  # 𝜅
    "\U0001d706": "l",  # 𝜆
    "\U0001d707": "m",  # 𝜇
    "\U0001d708": "n",  # 𝜈
    "\U0001d709": "ks",  # 𝜉
    "\U0001d70a": "o",  # 𝜊
    "\U0001d70b": "p",  # 𝜋
    "\U0001d70c": "r",  # 𝜌
    "\U0001d70d": "s",  # 𝜍
    "\U0001d70e": "s",  # 𝜎
    "\U0001d70f": "t",  # 𝜏
    "\U0001d710": "y",  # 𝜐
    "\U0001d711": "f",  # 𝜑
    "\U0001d712": "x",  # 𝜒
    "\U0001d713": "ps",  # 𝜓
    "\U0001d714": "o",  # 𝜔
    "\U0001d715": "d",  # 𝜕
    "\U0001d716": "E",  # 𝜖
    "\U0001d717": "TH",  # 𝜗
    "\U0001d718": "K",  # 𝜘
    "\U0001d719": "f",  # 𝜙
    "\U0001d71a": "r",  # 𝜚
    "\U0001d71b": "p",  # 𝜛
    "\U0001d71c": "A",  # 𝜜
    "\U0001d71d": "V",  # 𝜝
    "\U0001d71e": "G",  # 𝜞
    "\U0001d71f": "D",  # 𝜟
    "\U0001d720": "E",  # 𝜠
    "\U0001d721": "Z",  # 𝜡
    "\U0001d722": "I",  # 𝜢
    "\U0001d723": "TH",  # 𝜣
    "\U0001d724": "I",  # 𝜤
    "\U0001d725": "K",  # 𝜥
    "\U0001d726": "L",  # 𝜦
    "\U0001d727": "M",  # 𝜧
    "\U0001d728": "N",  # 𝜨
    "\U0001d729": "KS",  # 𝜩
    "\U0001d72a": "O",  # 𝜪
    "\U0001d72b": "P",  # 𝜫
    "\U0001d72c": "S",  # 𝜬
    "\U0001d72d": "TH",  # 𝜭
    "\U0001d72e": "S",  # 𝜮
    "\U0001d72f": "T",  # 𝜯
    "\U0001d730": "Y",  # 𝜰
    "\U0001d731": "F",  # 𝜱
    "\U0001d732": "X",  # 𝜲
    "\U0001d733": "PS",  # 𝜳
    "\U0001d734": "O",  # 𝜴
    "\U0001d735": "D",  # 𝜵
    "\U0001d736": "a",  # 𝜶
    "\U0001d737": "v",  # 𝜷
    "\U0001d738": "g",  # 𝜸
    "\U0001d739": "d",  # 𝜹
    "\U0001d73a": "e",  # 𝜺
    "\U0001d73b": "z",  # 𝜻
    "\U0001d73c": "i",  # 𝜼
    "\U0001d73d": "th",  # 𝜽
    "\U0001d73e": "i",  # 𝜾
    "\U0001d73f": "k",  # 𝜿
    "\U0001d740": "l",  # 𝝀
    "\U0001d741": "m",  # 𝝁
    "\U0001d742": "n",  # 𝝂
    "\U0001d743": "ks",  # 𝝃
    "\U0001d744": "o",  # 𝝄
    "\U0001d745": "p",  # 𝝅
    "\U0001d746": "r",  # 𝝆
    "\U0001d747": "s",  # 𝝇
    "\U0001d748": "s",  # 𝝈
    "\U0001d749": "t",  # 𝝉
    "\U0001d74a": "y",  # 𝝊
    "\U0001d74b": "f",  # 𝝋
    "\U0001d74c": "x",  # 𝝌
    "\U0001d74d": "ps",  # 𝝍
    "\U0001d74e": "o",  # 𝝎
    "\U0001d74f": "a",  # 𝝏
    "\U0001d750": "e",  # 𝝐
    "\U0001d751": "i",  # 𝝑
    "\U0001d752": "k",  # 𝝒
    "\U0001d753": "f",  # 𝝓
    "\U0001d754": "r",  # 𝝔
    "\U0001d755": "p",  # 𝝕
    "\U0001d756": "A",  # 𝝖
    "\U0001d757": "B",  # 𝝗
    "\U0001d758": "G",  # 𝝘
    "\U0001d759": "D",  # 𝝙
    "\U0001d75a": "E",  # 𝝚
    "\U0001d75b": "Z",  # 𝝛
    "\U0001d75c": "I",  # 𝝜
    "\U0001d75d": "TH",  # 𝝝
    "\U0001d75e": "I",  # 𝝞
    "\U0001d75f": "K",  # 𝝟
    "\U0001d760": "L",  # 𝝠
    "\U0001d761": "M",  # 𝝡
    "\U0001d762": "N",  # 𝝢
    "\U0001d763": "KS",  # 𝝣
    "\U0001d764": "O",  # 𝝤
    "\U0001d765": "P",  # 𝝥
    "\U0001d766": "R",  # 𝝦
    "\U0001d767": "TH",  # 𝝧
    "\U0001d768": "S",  # 𝝨
    "\U0001d769": "T",  # 𝝩
    "\U0001d76a": "Y",  # 𝝪
    "\U0001d76b": "F",  # 𝝫
    "\U0001d76c": "X",  # 𝝬
    "\U0001d76d": "PS",  # 𝝭
    "\U0001d76e": "O",  # 𝝮
    "\U0001d76f": "D",  # 𝝯
    "\U0001d770": "a",  # 𝝰
    "\U0001d771": "v",  # 𝝱
    "\U0001d772": "g",  # 𝝲
    "\U0001d773": "d",  # 𝝳
    "\U0001d774": "e",  # 𝝴
    "\U0001d775": "z",  # 𝝵
    "\U0001d776": "i",  # 𝝶
    "\U0001d777": "th",  # 𝝷
    "\U0001d778": "i",  # 𝝸
    "\U0001d779": "k",  # 𝝹
    "\U0001d77a": "l",  # 𝝺
    "\U0001d77b": "m",  # 𝝻
    "\U0001d77c": "n",  # 𝝼
    "\U0001d77d": "ks",  # 𝝽
    "\U0001d77e": "o",  # 𝝾
    "\U0001d77f": "p",  # 𝝿
    "\U0001d780": "r",  # 𝞀
    "\U0001d781": "s",  # 𝞁
    "\U0001d782": "s",  # 𝞂
    "\U0001d783": "t",  # 𝞃
    "\U0001d784": "y",  # 𝞄
    "\U0001d785": "f",  # 𝞅
    "\U0001d786": "x",  # 𝞆
    "\U0001d787": "ps",  # 𝞇
    "\U0001d788": "o",  # 𝞈
    "\U0001d789": "a",  # 𝞉
    "\U0001d78a": "e",  # 𝞊
    "\U0001d78b": "i",  # 𝞋
    "\U0001d78c": "k",  # 𝞌
    "\U0001d78d": "f",  # 𝞍
    "\U0001d78e": "r",  # 𝞎
    "\U0001d78f": "p",  # 𝞏
    "\U0001d790": "A",  # 𝞐
    "\U0001d791": "V",  # 𝞑
    "\U0001d792": "G",  # 𝞒
    "\U0001d793": "D",  # 𝞓
    "\U0001d794": "E",  # 𝞔
    "\U0001d795": "Z",  # 𝞕
    "\U0001d796": "I",  # 𝞖
    "\U0001d797": "TH",  # 𝞗
    "\U0001d798": "I",  # 𝞘
    "\U0001d799": "K",  # 𝞙
    "\U0001d79a": "L",  # 𝞚
    "\U0001d79b": "M",  # 𝞛
    "\U0001d79c": "N",  # 𝞜
    "\U0001d79d": "KS",  # 𝞝
    "\U0001d79e": "O",  # 𝞞
    "\U0001d79f": "P",  # 𝞟
    "\U0001d7a0": "S",  # 𝞠
    "\U0001d7a1": "TH",  # 𝞡
    "\U0001d7a2": "S",  # 𝞢
    "\U0001d7a3": "T",  # 𝞣
    "\U0001d7a4": "Y",  # 𝞤
    "\U0001d7a5": "F",  # 𝞥
    "\U0001d7a6": "X",  # 𝞦
    "\U0001d7a7": "PS",  # 𝞧
    "\U0001d7a8": "O",  # 𝞨
    "\U0001d7a9": "D",  # 𝞩
    "\U0001d7aa": "av",  # 𝞪
    "\U0001d7ab": "g",  # 𝞫
    "\U0001d7ac": "d",  # 𝞬
    "\U0001d7ad": "e",  # 𝞭
    "\U0001d7ae": "z",  # 𝞮
    "\U0001d7af": "i",  # 𝞯
    "\U0001d7b0": "i",  # 𝞰
    "\U0001d7b1": "th",  # 𝞱
    "\U0001d7b2": "i",  # 𝞲
    "\U0001d7b3": "k",  # 𝞳
    "\U0001d7b4": "l",  # 𝞴
    "\U0001d7b5": "m",  # 𝞵
    "\U0001d7b6": "n",  # 𝞶
    "\U0001d7b7": "ks",  # 𝞷
    "\U0001d7b8": "o",  # 𝞸
    "\U0001d7b9": "p",  # 𝞹
    "\U0001d7ba": "r",  # 𝞺
    "\U0001d7bb": "s",  # 𝞻
    "\U0001d7bc": "s",  # 𝞼
    "\U0001d7bd": "t",  # 𝞽
    "\U0001d7be": "y",  # 𝞾
    "\U0001d7bf": "f",  # 𝞿
    "\U0001d7c0": "x",  # 𝟀
    "\U0001d7c1": "ps",  # 𝟁
    "\U0001d7c2": "o",  # 𝟂
    "\U0001d7c3": "a",  # 𝟃
    "\U0001d7c4": "e",  # 𝟄
    "\U0001d7c5": "i",  # 𝟅
    "\U0001d7c6": "k",  # 𝟆
    "\U0001d7c7": "f",  # 𝟇
    "\U0001d7c8": "r",  # 𝟈
    "\U0001d7c9": "p",  # 𝟉
    "\U0001d7ca": "F",  # 𝟊
    "\U0001d7cb": "f",  # 𝟋
    "\u249c": "(a)",  # ⒜
    "\u249d": "(b)",  # ⒝
    "\u249e": "(c)",  # ⒞
    "\u249f": "(d)",  # ⒟
    "\u24a0": "(e)",  # ⒠
    "\u24a1": "(f)",  # ⒡
    "\u24a2": "(g)",  # ⒢
    "\u24a3": "(h)",  # ⒣
    "\u24a4": "(i)",  # ⒤
    "\u24a5": "(j)",  # ⒥
    "\u24a6": "(k)",  # ⒦
    "\u24a7": "(l)",  # ⒧
    "\u24a8": "(m)",  # ⒨
    "\u24a9": "(n)",  # ⒩
    "\u24aa": "(o)",  # ⒪
    "\u24ab": "(p)",  # ⒫
    "\u24ac": "(q)",  # ⒬
    "\u24ad": "(r)",  # ⒭
    "\u24ae": "(s)",  # ⒮
    "\u24af": "(t)",  # ⒯
    "\u24b0": "(u)",  # ⒰
    "\u24b1": "(v)",  # ⒱
    "\u24b2": "(w)",  # ⒲
    "\u24b3": "(x)",  # ⒳
    "\u24b4": "(y)",  # ⒴
    "\u24b5": "(z)",  # ⒵
    "\u24b6": "(A)",  # Ⓐ
    "\u24b7": "(B)",  # Ⓑ
    "\u24b8": "(C)",  # Ⓒ
    "\u24b9": "(D)",  # Ⓓ
    "\u24ba": "(E)",  # Ⓔ
    "\u24bb": "(F)",  # Ⓕ
    "\u24bc": "(G)",  # Ⓖ
    "\u24bd": "(H)",  # Ⓗ
    "\u24be": "(I)",  # Ⓘ
    "\u24bf": "(J)",  # Ⓙ
    "\u24c0": "(K)",  # Ⓚ
    "\u24c1": "(L)",  # Ⓛ
    "\u24c3": "(N)",  # Ⓝ
    "\u24c4": "(O)",  # Ⓞ
    "\u24c5": "(P)",  # Ⓟ
    "\u24c6": "(Q)",  # Ⓠ
    "\u24c7": "(R)",  # Ⓡ
    "\u24c8": "(S)",  # Ⓢ
    "\u24c9": "(T)",  # Ⓣ
    "\u24ca": "(U)",  # Ⓤ
    "\u24cb": "(V)",  # Ⓥ
    "\u24cc": "(W)",  # Ⓦ
    "\u24cd": "(X)",  # Ⓧ
    "\u24ce": "(Y)",  # Ⓨ
    "\u24cf": "(Z)",  # Ⓩ
    "\u24d0": "(a)",  # ⓐ
    "\u24d1": "(b)",  # ⓑ
    "\u24d2": "(b)",  # ⓒ
    "\u24d3": "(c)",  # ⓓ
    "\u24d4": "(e)",  # ⓔ
    "\u24d5": "(f)",  # ⓕ
    "\u24d6": "(g)",  # ⓖ
    "\u24d7": "(h)",  # ⓗ
    "\u24d8": "(i)",  # ⓘ
    "\u24d9": "(j)",  # ⓙ
    "\u24da": "(k)",  # ⓚ
    "\u24db": "(l)",  # ⓛ
    "\u24dc": "(m)",  # ⓜ
    "\u24dd": "(n)",  # ⓝ
    "\u24de": "(o)",  # ⓞ
    "\u24df": "(p)",  # ⓟ
    "\u24e0": "(q)",  # ⓠ
    "\u24e1": "(r)",  # ⓡ
    "\u24e2": "(s)",  # ⓢ
    "\u24e3": "(t)",  # ⓣ
    "\u24e4": "(u)",  # ⓤ
    "\u24e5": "(v)",  # ⓥ
    "\u24e6": "(w)",  # ⓦ
    "\u24e7": "(x)",  # ⓧ
    "\u24e8": "(y)",  # ⓨ
    "\u24e9": "(z)",  # ⓩ
    # Maltese
    "\u010a": "C",  # Ċ
    "\u010b": "c",  # ċ
    "\u0120": "G",  # Ġ
    "\u0121": "g",  # ġ
    "\u0126": "H",  # Ħ
    "\u0127": "h",  # ħ
    # Numbers
    "\U0001d7ce": "0",  # 𝟎
    "\U0001d7cf": "1",  # 𝟏
    "\U0001d7d0": "2",  # 𝟐
    "\U0001d7d1": "3",  # 𝟑
    "\U0001d7d2": "4",  # 𝟒
    "\U0001d7d3": "5",  # 𝟓
    "\U0001d7d4": "6",  # 𝟔
    "\U0001d7d5": "7",  # 𝟕
    "\U0001d7d6": "8",  # 𝟖
    "\U0001d7d7": "9",  # 𝟗
    "\U0001d7d8": "0",  # 𝟘
    "\U0001d7d9": "1",  # 𝟙
    "\U0001d7da": "2",  # 𝟚
    "\U0001d7db": "3",  # 𝟛
    "\U0001d7dc": "4",  # 𝟜
    "\U0001d7dd": "5",  # 𝟝
    "\U0001d7de": "6",  # 𝟞
    "\U0001d7df": "7",  # 𝟟
    "\U0001d7e0": "8",  # 𝟠
    "\U0001d7e1": "9",  # 𝟡
    "\U0001d7e2": "0",  # 𝟢
    "\U0001d7e3": "1",  # 𝟣
    "\U0001d7e4": "2",  # 𝟤
    "\U0001d7e5": "3",  # 𝟥
    "\U0001d7e6": "4",  # 𝟦
    "\U0001d7e7": "5",  # 𝟧
    "\U0001d7e8": "6",  # 𝟨
    "\U0001d7e9": "7",  # 𝟩
    "\U0001d7ea": "8",  # 𝟪
    "\U0001d7eb": "9",  # 𝟫
    "\U0001d7ec": "0",  # 𝟬
    "\U0001d7ed": "1",  # 𝟭
    "\U0001d7ee": "2",  # 𝟮
    "\U0001d7ef": "3",  # 𝟯
    "\U0001d7f0": "4",  # 𝟰
    "\U0001d7f1": "5",  # 𝟱
    "\U0001d7f2": "6",  # 𝟲
    "\U0001d7f3": "7",  # 𝟳
    "\U0001d7f4": "8",  # 𝟴
    "\U0001d7f5": "9",  # 𝟵
    "\U0001d7f6": "0",  # 𝟶
    "\U0001d7f7": "1",  # 𝟷
    "\U0001d7f8": "2",  # 𝟸
    "\U0001d7f9": "3",  # 𝟹
    "\U0001d7fa": "4",  # 𝟺
    "\U0001d7fb": "5",  # 𝟻
    "\U0001d7fc": "6",  # 𝟼
    "\U0001d7fd": "7",  # 𝟽
    "\U0001d7fe": "8",  # 𝟾
    "\U0001d7ff": "9",  # 𝟿
    "\u2460": "1",  # ①
    "\u2461": "2",  # ②
    "\u2462": "3",  # ③
    "\u2463": "4",  # ④
    "\u2464": "5",  # ⑤
    "\u2465": "6",  # ⑥
    "\u2466": "7",  # ⑦
    "\u2467": "8",  # ⑧
    "\u2468": "9",  # ⑨
    "\u2469": "10",  # ⑩
    "\u246a": "11",  # ⑪
    "\u246b": "12",  # ⑫
    "\u246c": "13",  # ⑬
    "\u246d": "14",  # ⑭
    "\u246e": "15",  # ⑮
    "\u246f": "16",  # ⑯
    "\u2470": "17",  # ⑰
    "\u2471": "18",  # ⑱
    "\u2472": "19",  # ⑲
    "\u2473": "20",  # ⑳
    "\u2474": "1",  # ⑴
    "\u2475": "2",  # ⑵
    "\u2476": "3",  # ⑶
    "\u2477": "4",  # ⑷
    "\u2478": "5",  # ⑸
    "\u2479": "6",  # ⑹
    "\u247a": "7",  # ⑺
    "\u247b": "8",  # ⑻
    "\u247c": "9",  # ⑼
    "\u247d": "10",  # ⑽
    "\u247e": "11",  # ⑾
    "\u247f": "12",  # ⑿
    "\u2480": "13",  # ⒀
    "\u2481": "14",  # ⒁
    "\u2482": "15",  # ⒂
    "\u2483": "16",  # ⒃
    "\u2484": "17",  # ⒄
    "\u2485": "18",  # ⒅
    "\u2486": "19",  # ⒆
    "\u2487": "20",  # ⒇
    "\u2488": "1.",  # ⒈
    "\u2489": "2.",  # ⒉
    "\u248a": "3.",  # ⒊
    "\u248b": "4.",  # ⒋
    "\u248c": "5.",  # ⒌
    "\u248d": "6.",  # ⒍
    "\u248e": "7.",  # ⒎
    "\u248f": "8.",  # ⒏
    "\u2490": "9.",  # ⒐
    "\u2491": "10.",  # ⒑
    "\u2492": "11.",  # ⒒
    "\u2493": "12.",  # ⒓
    "\u2494": "13.",  # ⒔
    "\u2495": "14.",  # ⒕
    "\u2496": "15.",  # ⒖
    "\u2497": "16.",  # ⒗
    "\u2498": "17.",  # ⒘
    "\u2499": "18.",  # ⒙
    "\u249a": "19.",  # ⒚
    "\u249b": "20.",  # ⒛
    "\u24ea": "0",  # ⓪
    "\u24eb": "11",  # ⓫
    "\u24ec": "12",  # ⓬
    "\u24ed": "13",  # ⓭
    "\u24ee": "14",  # ⓮
    "\u24ef": "15",  # ⓯
    "\u24f0": "16",  # ⓰
    "\u24f1": "17",  # ⓱
    "\u24f2": "18",  # ⓲
    "\u24f3": "19",  # ⓳
    "\u24f4": "20",  # ⓴
    "\u24f5": "1",  # ⓵
    "\u24f6": "2",  # ⓶
    "\u24f7": "3",  # ⓷
    "\u24f8": "4",  # ⓸
    "\u24f9": "5",  # ⓹
    "\u24fa": "6",  # ⓺
    "\u24fb": "7",  # ⓻
    "\u24fc": "8",  # ⓼
    "\u24fd": "9",  # ⓽
    "\u24fe": "10",  # ⓾
    "\u24ff": "0",  # ⓿
    # Punctuation
    "\U0001f670": "&",  # 🙰
    "\U0001f671": "&",  # 🙱
    "\U0001f672": "&",  # 🙲
    "\U0001f673": "&",  # 🙳
    "\U0001f674": "&",  # 🙴
    "\U0001f675": "&",  # 🙵
    "U+1F676": '"',  # 🙶
    "U+1F677": '"',  # 🙷
    "U+1F678": '"',  # 🙸
    "\u203d": "?!",  # ‽
    "\U0001f679": "?!",  # 🙹
    "\U0001f67a": "?!",  # 🙺
    "\U0001f67b": "?!",  # 🙻
    "\U0001f67c": "/",  # 🙼
    "\U0001f67d": "\\",  # 🙽
    # Alchemy
    "\U0001f707": "AR",  # 🜇
    "\U0001f708": "V",  # 🜈
    "\U0001f709": "V",  # 🜉
    "\U0001f706": "VR",  # 🜆
    "\U0001f705": "VF",  # 🜅
    "\U0001f729": "2",  # 🜩
    "\U0001f72a": "5",  # 🜪
    "\U0001f761": "f",  # 🝡
    "\U0001f762": "W",  # 🝢
    "\U0001f763": "U",  # 🝣
    "\U0001f767": "V",  # 🝧
    "\U0001f768": "T",  # 🝨
    "\U0001f76a": "V",  # 🝪
    "\U0001f76b": "MB",  # 🝫
    "\U0001f76c": "VB",  # 🝬
    "\U0001f772": "3B",  # 🝲
    "\U0001f773": "3B",  # 🝳
    "\u01cd": "A",  # Ǎ
    "\u0200": "A",  # Ȁ
    "\u0202": "A",  # Ȃ
    "\u0226": "A",  # Ȧ
    "\u01ce": "a",  # ǎ
    "\u0201": "a",  # ȁ
    "\u0203": "a",  # ȃ
    "\u0227": "a",  # ȧ
    "\u0180": "b",  # ƀ
    "\u0183": "b",  # ƃ
    "\u0108": "C",  # Ĉ
    "\u0109": "c",  # ĉ
    "\u1e0c": "D",  # Ḍ
    "\u1e10": "D",  # Ḑ
    "\u1e12": "D",  # Ḓ
    "\u1e0d": "d",  # ḍ
    "\u1e11": "d",  # ḑ
    "\u1e13": "d",  # ḓ
    "\u0204": "E",  # Ȅ
    "\u0206": "E",  # Ȇ
    "\u0228": "E",  # Ȩ
    "\u0115": "e",  # ĕ
    "\u0205": "e",  # ȅ
    "\u0207": "e",  # ȇ
    "\u0229": "e",  # ȩ
    "\u0192": "f",  # ƒ
    "\u011c": "G",  # Ĝ
    "\u01e6": "G",  # Ǧ
    "\u01f4": "G",  # Ǵ
    "\u011d": "g",  # ĝ
    "\u01e7": "g",  # ǧ
    "\u01f5": "g",  # ǵ
    "\u0124": "H",  # Ĥ
    "\u021e": "H",  # Ȟ
    "\u1e24": "H",  # Ḥ
    "\u1e26": "H",  # Ḧ
    "\u1e28": "H",  # Ḩ
    "\u1e2a": "H",  # Ḫ
    "\u0125": "h",  # ĥ
    "\u021f": "h",  # ȟ
    "\u1e25": "h",  # ḥ
    "\u1e27": "h",  # ḧ
    "\u1e29": "h",  # ḩ
    "\u1e2b": "h",  # ḫ
    "\u012c": "I",  # Ĭ
    "\u01cf": "I",  # Ǐ
    "\u0208": "I",  # Ȉ
    "\u020a": "I",  # Ȋ
    "\u012d": "i",  # ĭ
    "\u01d0": "i",  # ǐ
    "\u0209": "i",  # ȉ
    "\u020b": "i",  # ȋ
    "\u0134": "J",  # Ĵ
    "\u0135": "j",  # ĵ
    "\u01e8": "K",  # Ǩ
    "\u1e30": "K",  # Ḱ
    "\u1e32": "K",  # Ḳ
    "\u1e34": "K",  # Ḵ
    "\u01e9": "k",  # ǩ
    "\u1e31": "k",  # ḱ
    "\u1e33": "k",  # ḳ
    "\u1e35": "k",  # ḵ
    "\u0139": "L",  # Ĺ
    "\u013d": "L",  # Ľ
    "\u013f": "L",  # Ŀ
    "\u013a": "l",  # ĺ
    "\u013e": "l",  # ľ
    "\u0140": "l",  # ŀ
    "\u1e3e": "M",  # Ḿ
    "\u1e40": "M",  # Ṁ
    "\u1e42": "M",  # Ṃ
    "\u1e3f": "m",  # ḿ
    "\u1e41": "m",  # ṁ
    "\u1e43": "m",  # ṃ
    "\u014a": "N",  # Ŋ
    "\u1e44": "N",  # Ṅ
    "\u1e46": "N",  # Ṇ
    "\u1e48": "N",  # Ṉ
    "\u1e4a": "N",  # Ṋ
    "\u014b": "n",  # ŋ
    "\u1e45": "n",  # ṅ
    "\u1e47": "n",  # ṇ
    "\u1e49": "n",  # ṉ
    "\u1e4b": "n",  # ṋ
    "\u014c": "O",  # Ō
    "\u014e": "O",  # Ŏ
    "\u01d1": "O",  # Ǒ
    "\u020c": "O",  # Ȍ
    "\u020e": "O",  # Ȏ
    "\u022a": "O",  # Ȫ
    "\u022c": "O",  # Ȭ
    "\u022e": "O",  # Ȯ
    "\u0230": "O",  # Ȱ
    "\u014d": "o",  # ō
    "\u014f": "o",  # ŏ
    "\u01d2": "o",  # ǒ
    "\u020d": "o",  # ȍ
    "\u020f": "o",  # ȏ
    "\u022b": "o",  # ȫ
    "\u022d": "o",  # ȭ
    "\u022f": "o",  # ȯ
    "\u0231": "o",  # ȱ
    "\u1e54": "P",  # Ṕ
    "\u1e56": "P",  # Ṗ
    "\u1e55": "p",  # ṕ
    "\u1e57": "p",  # ṗ
    "\u0154": "R",  # Ŕ
    "\u0156": "R",  # Ŗ
    "\u0210": "R",  # Ȑ
    "\u0212": "R",  # Ȓ
    "\u1e58": "R",  # Ṙ
    "\u1e5a": "R",  # Ṛ
    "\u1e5e": "R",  # Ṟ
    "\u0155": "r",  # ŕ
    "\u0157": "r",  # ŗ
    "\u0211": "r",  # ȑ
    "\u0213": "r",  # ȓ
    "\u1e59": "r",  # ṙ
    "\u1e5b": "r",  # ṛ
    "\u1e5f": "r",  # ṟ
    "\u015c": "S",  # Ŝ
    "\u1e60": "S",  # Ṡ
    "\u1e62": "S",  # Ṣ
    "\u015d": "s",  # ŝ
    "\u1e61": "s",  # ṡ
    "\u1e63": "s",  # ṣ
    "\u0166": "T",  # Ŧ
    "\u1e6a": "T",  # Ṫ
    "\u1e6c": "T",  # Ṭ
    "\u1e6e": "T",  # Ṯ
    "\u1e70": "T",  # Ṱ
    "\u0167": "t",  # ŧ
    "\u1e6b": "t",  # ṫ
    "\u1e6d": "t",  # ṭ
    "\u1e6f": "t",  # ṯ
    "\u1e71": "t",  # ṱ
    "\u016c": "U",  # Ŭ
    "\u01d3": "U",  # Ǔ
    "\u0214": "U",  # Ȕ
    "\u0216": "U",  # Ȗ
    "\u016d": "u",  # ŭ
    "\u01d4": "u",  # ǔ
    "\u0215": "u",  # ȕ
    "\u0217": "u",  # ȗ
    "\u1e7c": "V",  # Ṽ
    "\u1e7e": "V",  # Ṿ
    "\u1e7d": "v",  # ṽ
    "\u1e7f": "v",  # ṿ
    "\u0174": "W",  # Ŵ
    "\u1e80": "W",  # Ẁ
    "\u1e82": "W",  # Ẃ
    "\u1e84": "W",  # Ẅ
    "\u1e86": "W",  # Ẇ
    "\u1e88": "W",  # Ẉ
    "\u0175": "w",  # ŵ
    "\u1e81": "w",  # ẁ
    "\u1e83": "w",  # ẃ
    "\u1e85": "w",  # ẅ
    "\u1e87": "w",  # ẇ
    "\u1e89": "w",  # ẉ
    "\u1e8a": "X",  # Ẋ
    "\u1e8c": "X",  # Ẍ
    "\u1e8b": "x",  # ẋ
    "\u1e8d": "x",  # ẍ
    "\u0176": "Y",  # Ŷ
    "\u0178": "Y",  # Ÿ
    "\u0232": "Y",  # Ȳ
    "\u1e8e": "Y",  # Ẏ
    "\u0177": "y",  # ŷ
    "\u0233": "y",  # ȳ
    "\u1e8f": "y",  # ẏ
    "\u1e90": "Z",  # Ẑ
    "\u1e92": "Z",  # Ẓ
    "\u1e94": "Z",  # Ẕ
    "\u1e91": "z",  # ẑ
    "\u1e93": "z",  # ẓ
    "\u1e95": "z",  # ẕ
}

emoji_mapping: Dict[str, str] = {
    """
    A dictionary intended to hold transliteration mappings specifically for emojis.

    Keys should be Unicode emoji characters or sequences (str) and values should
    be their desired ASCII text representations (str), such as shortcodes or
    descriptive words. This mapping allows for converting graphical emojis
    into readable text within the ASCII range.
    """
    # Smileys & Emotion
    # face-smiling
    "\U0001f600": "grinning face",
    "\U0001f603": "grinning face with big eyes",
    "\U0001f604": "grinning face with smiling eyes",
    "\U0001f601": "beaming face with smiling eyes",
    "\U0001f606": "grinning squinting face",
    "\U0001f605": "grinning face with sweat",
    "\U0001f923": "rolling on the floor laughing",
    "\U0001f602": "face with tears of joy",
    "\U0001f642": "slightly smiling face",
    "\U0001f643": "upside-down face",
    "\U0001fae0": "melting face",
    "\U0001f609": "winking face",
    "\U0001f60a": "smiling face with smiling eyes",
    "\U0001f607": "smiling face with halo",
    # face-affection
    "\U0001f970": "smiling face with hearts",
    "\U0001f60d": "smiling face with heart-eyes",
    "\U0001f929": "star-struck",
    "\U0001f618": "face blowing a kiss",
    "\U0001f617": "kissing face",
    "\u263a": "smiling face",
    "\U0001f61a": "kissing face with closed eyes",
    "\U0001f619": "kissing face with smiling eyes",
    "\U0001f972": "smiling face with tear",
    # face-tongue
    "\U0001f60b": "face savoring food",
    "\U0001f61b": "face with tongue",
    "\U0001f61c": "winking face with tongue",
    "\U0001f92a": "zany face",
    "\U0001f61d": "squinting face with tongue",
    "\U0001f911": "money-mouth face",
    # face-hand
    "\U0001f917": "smiling face with open hands",
    "\U0001f92d": "face with hand over mouth",
    "\U0001fae2": "face with open eyes and hand over mouth",
    "\U0001fae3": "face with peeking eye",
    "\U0001f92b": "shushing face",
    "\U0001f914": "thinking face",
    "\U0001fae1": "saluting face",
    # face-neutral-skeptical
    "\U0001f910": "zipper-mouth face",
    "\U0001f928": "face with raised eyebrow",
    "\U0001f610": "neutral face",
    "\U0001f611": "expressionless face",
    "\U0001f636": "face without mouth",
    "\U0001fae5": "dotted line face",
    "\U0001f636\u200d\U0001f32b\ufe0f": "face in clouds",
    "\U0001f60f": "smirking face",
    "\U0001f612": "unamused face",
    "\U0001f644": "face with rolling eyes",
    "\U0001f62c": "grimacing face",
    "\U0001f62e\u200d\U0001f4a8": "face exhaling",
    "\U0001f925": "lying face",
    "\U0001fae8": "shaking face",
    "\U0001f642\u200d\u2194\ufe0f": "head shaking horizontally",
    "\U0001f642\u200d\u2195\ufe0f": "head shaking vertically",
    # face-sleepy
    "\U0001f60c": "relieved face",
    "\U0001f614": "pensive face",
    "\U0001f62a": "sleepy face",
    "\U0001f924": "drooling face",
    "\U0001f634": "sleeping face",
    "\U0001fae9": "face with bags under eyes",
    # face-unwell
    "\U0001f637": "face with medical mask",
    "\U0001f912": "face with thermometer",
    "\U0001f915": "face with head-bandage",
    "\U0001f922": "nauseated face",
    "\U0001f92e": "face vomiting",
    "\U0001f927": "sneezing face",
    "\U0001f975": "hot face",
    "\U0001f976": "cold face",
    "\U0001f974": "woozy face",
    "\U0001f635": "face with crossed-out eyes",
    "\U0001f635\u200d\U0001f4ab": "face with spiral eyes",
    "\U0001f92f": "exploding head",
    # face-hat
    "\U0001f920": "cowboy hat face",
    "\U0001f973": "partying face",
    "\U0001f978": "disguised face",
    # face-glasses
    "\U0001f60e": "smiling face with sunglasses",
    "\U0001f913": "nerd face",
    "\U0001f9d0": "face with monocle",
    # face-concerned
    "\U0001f615": "confused face",
    "\U0001fae4": "face with diagonal mouth",
    "\U0001f61f": "worried face",
    "\U0001f641": "slightly frowning face",
    "\u2639": "frowning face",
    "\U0001f62e": "face with open mouth",
    "\U0001f62f": "hushed face",
    "\U0001f632": "astonished face",
    "\U0001f633": "flushed face",
    "\U0001f97a": "pleading face",
    "\U0001f979": "face holding back tears",
    "\U0001f626": "frowning face with open mouth",
    "\U0001f627": "anguished face",
    "\U0001f628": "fearful face",
    "\U0001f630": "anxious face with sweat",
    "\U0001f625": "sad but relieved face",
    "\U0001f622": "crying face",
    "\U0001f62d": "loudly crying face",
    "\U0001f631": "face screaming in fear",
    "\U0001f616": "confounded face",
    "\U0001f623": "persevering face",
    "\U0001f61e": "disappointed face",
    "\U0001f613": "downcast face with sweat",
    "\U0001f629": "weary face",
    "\U0001f62b": "tired face",
    "\U0001f971": "yawning face",
    # face-negative
    "\U0001f624": "face with steam from nose",
    "\U0001f621": "enraged face",
    "\U0001f620": "angry face",
    "\U0001f92c": "face with symbols on mouth",
    "\U0001f608": "smiling face with horns",
    "\U0001f47f": "angry face with horns",
    "\U0001f480": "skull",
    "\u2620": "skull and crossbones",
    # face-costume
    "\U0001f4a9": "pile of poo",
    "\U0001f921": "clown face",
    "\U0001f479": "ogre",
    "\U0001f47a": "goblin",
    "\U0001f47b": "ghost",
    "\U0001f47d": "alien",
    "\U0001f47e": "alien monster",
    "\U0001f916": "robot",
    # cat-face
    "\U0001f63a": "grinning cat",
    "\U0001f638": "grinning cat with smiling eyes",
    "\U0001f639": "cat with tears of joy",
    "\U0001f63b": "smiling cat with heart-eyes",
    "\U0001f63c": "cat with wry smile",
    "\U0001f63d": "kissing cat",
    "\U0001f640": "weary cat",
    "\U0001f63f": "crying cat",
    "\U0001f63e": "pouting cat",
    # monkey-face
    "\U0001f648": "see-no-evil monkey",
    "\U0001f649": "hear-no-evil monkey",
    "\U0001f64a": "speak-no-evil monkey",
    # heart
    "\U0001f48c": "love letter",
    "\U0001f498": "heart with arrow",
    "\U0001f49d": "heart with ribbon",
    "\U0001f496": "sparkling heart",
    "\U0001f497": "growing heart",
    "\U0001f493": "beating heart",
    "\U0001f49e": "revolving hearts",
    "\U0001f495": "two hearts",
    "\U0001f49f": "heart decoration",
    "\u2763": "heart exclamation",
    "\U0001f494": "broken heart",
    "\u2764\ufe0f\u200d\U0001f525": "heart on fire",
    "\u2764\ufe0f\u200d\U0001fa79": "mending heart",
    "\u2764": "red heart",
    "\U0001fa77": "pink heart",
    "\U0001f9e1": "orange heart",
    "\U0001f49b": "yellow heart",
    "\U0001f49a": "green heart",
    "\U0001f499": "blue heart",
    "\U0001fa75": "light blue heart",
    "\U0001f49c": "purple heart",
    "\U0001f90e": "brown heart",
    "\U0001f5a4": "black heart",
    "\U0001fa76": "grey heart",
    "\U0001f90d": "white heart",
    # emotion
    "\U0001f48b": "kiss mark",
    "\U0001f4af": "hundred points",
    "\U0001f4a2": "anger symbol",
    "\U0001f4a5": "collision",
    "\U0001f4ab": "dizzy",
    "\U0001f4a6": "sweat droplets",
    "\U0001f4a8": "dashing away",
    "\U0001f573": "hole",
    "\U0001f4ac": "speech balloon",
    "\U0001f441\ufe0f\u200d\U0001f5e8\ufe0f": "eye in speech bubble",
    "\U0001f5e8": "left speech bubble",
    "\U0001f5ef": "right anger bubble",
    "\U0001f4ad": "thought balloon",
    "\U0001f4a4": "ZZZ",
    # People & Body
    # hand-fingers-open
    "\U0001f44b": "waving hand",
    "\U0001f91a": "raised back of hand",
    "\U0001f590": "hand with fingers splayed",
    "\u270b": "raised hand",
    "\U0001f596": "vulcan salute",
    "\U0001faf1": "rightwards hand",
    "\U0001faf2": "leftwards hand",
    "\U0001faf3": "palm down hand",
    "\U0001faf4": "palm up hand",
    "\U0001faf7": "leftwards pushing hand",
    "\U0001faf8": "rightwards pushing hand",
    # hand-fingers-partial
    "\U0001f44c": "OK hand",
    "\U0001f90c": "pinched fingers",
    "\U0001f90f": "pinching hand",
    "\u270c": "victory hand",
    "\U0001f91e": "crossed fingers",
    "\U0001faf0": "hand with index finger and thumb crossed",
    "\U0001f91f": "love-you gesture",
    "\U0001f918": "sign of the horns",
    "\U0001f919": "call me hand",
    # hand-single-finger
    "\U0001f448": "backhand index pointing left",
    "\U0001f449": "backhand index pointing right",
    "\U0001f446": "backhand index pointing up",
    "\U0001f595": "middle finger",
    "\U0001f447": "backhand index pointing down",
    "\u261d": "index pointing up",
    "\U0001faf5": "index pointing at the viewer",
    # hand-fingers-closed
    "\U0001f44d": "thumbs up",
    "\U0001f44e": "thumbs down",
    "\u270a": "raised fist",
    "\U0001f44a": "oncoming fist",
    "\U0001f91b": "left-facing fist",
    "\U0001f91c": "right-facing fist",
    # hands
    "\U0001f44f": "clapping hands",
    "\U0001f64c": "raising hands",
    "\U0001faf6": "heart hands",
    "\U0001f450": "open hands",
    "\U0001f932": "palms up together",
    "\U0001f91d": "handshake",
    "\U0001f64f": "folded hands",
    # hand-prop
    "\u270d": "writing hand",
    "\U0001f485": "nail polish",
    "\U0001f933": "selfie",
    # body-parts
    "\U0001f4aa": "flexed biceps",
    "\U0001f9be": "mechanical arm",
    "\U0001f9bf": "mechanical leg",
    "\U0001f9b5": "leg",
    "\U0001f9b6": "foot",
    "\U0001f442": "ear",
    "\U0001f9bb": "ear with hearing aid",
    "\U0001f443": "nose",
    "\U0001f9e0": "brain",
    "\U0001fac0": "anatomical heart",
    "\U0001fac1": "lungs",
    "\U0001f9b7": "tooth",
    "\U0001f9b4": "bone",
    "\U0001f440": "eyes",
    "\U0001f441": "eye",
    "\U0001f445": "tongue",
    "\U0001f444": "mouth",
    "\U0001fae6": "biting lip",
    # person
    "\U0001f476": "baby",
    "\U0001f9d2": "child",
    "\U0001f466": "boy",
    "\U0001f467": "girl",
    "\U0001f9d1": "person",
    "\U0001f471": "person: blond hair",
    "\U0001f468": "man",
    "\U0001f9d4": "person: beard",
    "\U0001f9d4\u200d\u2642\ufe0f": "man: beard",
    "\U0001f9d4\u200d\u2640\ufe0f": "woman: beard",
    "\U0001f468\u200d\U0001f9b0": "man: red hair",
    "\U0001f468\u200d\U0001f9b1": "man: curly hair",
    "\U0001f468\u200d\U0001f9b3": "man: white hair",
    "\U0001f468\u200d\U0001f9b2": "man: bald",
    "\U0001f469": "woman",
    "\U0001f469\u200d\U0001f9b0": "woman: red hair",
    "\U0001f9d1\u200d\U0001f9b0": "person: red hair",
    "\U0001f469\u200d\U0001f9b1": "woman: curly hair",
    "\U0001f9d1\u200d\U0001f9b1": "person: curly hair",
    "\U0001f469\u200d\U0001f9b3": "woman: white hair",
    "\U0001f9d1\u200d\U0001f9b3": "person: white hair",
    "\U0001f469\u200d\U0001f9b2": "woman: bald",
    "\U0001f9d1\u200d\U0001f9b2": "person: bald",
    "\U0001f471\u200d\u2640\ufe0f": "woman: blond hair",
    "\U0001f471\u200d\u2642\ufe0f": "man: blond hair",
    "\U0001f9d3": "older person",
    "\U0001f474": "old man",
    "\U0001f475": "old woman",
    # person-gesture
    "\U0001f64d": "person frowning",
    "\U0001f64d\u200d\u2642\ufe0f": "man frowning",
    "\U0001f64d\u200d\u2640\ufe0f": "woman frowning",
    "\U0001f64e": "person pouting",
    "\U0001f64e\u200d\u2642\ufe0f": "man pouting",
    "\U0001f64e\u200d\u2640\ufe0f": "woman pouting",
    "\U0001f645": "person gesturing NO",
    "\U0001f645\u200d\u2642\ufe0f": "man gesturing NO",
    "\U0001f645\u200d\u2640\ufe0f": "woman gesturing NO",
    "\U0001f646": "person gesturing OK",
    "\U0001f646\u200d\u2642\ufe0f": "man gesturing OK",
    "\U0001f646\u200d\u2640\ufe0f": "woman gesturing OK",
    "\U0001f481": "person tipping hand",
    "\U0001f481\u200d\u2642\ufe0f": "man tipping hand",
    "\U0001f481\u200d\u2640\ufe0f": "woman tipping hand",
    "\U0001f64b": "person raising hand",
    "\U0001f64b\u200d\u2642\ufe0f": "man raising hand",
    "\U0001f64b\u200d\u2640\ufe0f": "woman raising hand",
    "\U0001f9cf": "deaf person",
    "\U0001f9cf\u200d\u2642\ufe0f": "deaf man",
    "\U0001f9cf\u200d\u2640\ufe0f": "deaf woman",
    "\U0001f647": "person bowing",
    "\U0001f647\u200d\u2642\ufe0f": "man bowing",
    "\U0001f647\u200d\u2640\ufe0f": "woman bowing",
    "\U0001f926": "person facepalming",
    "\U0001f926\u200d\u2642\ufe0f": "man facepalming",
    "\U0001f926\u200d\u2640\ufe0f": "woman facepalming",
    "\U0001f937": "person shrugging",
    "\U0001f937\u200d\u2642\ufe0f": "man shrugging",
    "\U0001f937\u200d\u2640\ufe0f": "woman shrugging",
    # person-role
    "\U0001f9d1\u200d\u2695\ufe0f": "health worker",
    "\U0001f468\u200d\u2695\ufe0f": "man health worker",
    "\U0001f469\u200d\u2695\ufe0f": "woman health worker",
    "\U0001f9d1\u200d\U0001f393": "student",
    "\U0001f468\u200d\U0001f393": "man student",
    "\U0001f469\u200d\U0001f393": "woman student",
    "\U0001f9d1\u200d\U0001f3eb": "teacher",
    "\U0001f468\u200d\U0001f3eb": "man teacher",
    "\U0001f469\u200d\U0001f3eb": "woman teacher",
    "\U0001f9d1\u200d\u2696\ufe0f": "judge",
    "\U0001f468\u200d\u2696\ufe0f": "man judge",
    "\U0001f469\u200d\u2696\ufe0f": "woman judge",
    "\U0001f9d1\u200d\U0001f33e": "farmer",
    "\U0001f468\u200d\U0001f33e": "man farmer",
    "\U0001f469\u200d\U0001f33e": "woman farmer",
    "\U0001f9d1\u200d\U0001f373": "cook",
    "\U0001f468\u200d\U0001f373": "man cook",
    "\U0001f469\u200d\U0001f373": "woman cook",
    "\U0001f9d1\u200d\U0001f527": "mechanic",
    "\U0001f468\u200d\U0001f527": "man mechanic",
    "\U0001f469\u200d\U0001f527": "woman mechanic",
    "\U0001f9d1\u200d\U0001f3ed": "factory worker",
    "\U0001f468\u200d\U0001f3ed": "man factory worker",
    "\U0001f469\u200d\U0001f3ed": "woman factory worker",
    "\U0001f9d1\u200d\U0001f4bc": "office worker",
    "\U0001f468\u200d\U0001f4bc": "man office worker",
    "\U0001f469\u200d\U0001f4bc": "woman office worker",
    "\U0001f9d1\u200d\U0001f52c": "scientist",
    "\U0001f468\u200d\U0001f52c": "man scientist",
    "\U0001f469\u200d\U0001f52c": "woman scientist",
    "\U0001f9d1\u200d\U0001f4bb": "technologist",
    "\U0001f468\u200d\U0001f4bb": "man technologist",
    "\U0001f469\u200d\U0001f4bb": "woman technologist",
    "\U0001f9d1\u200d\U0001f3a4": "singer",
    "\U0001f468\u200d\U0001f3a4": "man singer",
    "\U0001f469\u200d\U0001f3a4": "woman singer",
    "\U0001f9d1\u200d\U0001f3a8": "artist",
    "\U0001f468\u200d\U0001f3a8": "man artist",
    "\U0001f469\u200d\U0001f3a8": "woman artist",
    "\U0001f9d1\u200d\u2708\ufe0f": "pilot",
    "\U0001f468\u200d\u2708\ufe0f": "man pilot",
    "\U0001f469\u200d\u2708\ufe0f": "woman pilot",
    "\U0001f9d1\u200d\U0001f680": "astronaut",
    "\U0001f468\u200d\U0001f680": "man astronaut",
    "\U0001f469\u200d\U0001f680": "woman astronaut",
    "\U0001f9d1\u200d\U0001f692": "firefighter",
    "\U0001f468\u200d\U0001f692": "man firefighter",
    "\U0001f469\u200d\U0001f692": "woman firefighter",
    "\U0001f46e": "police officer",
    "\U0001f46e\u200d\u2642\ufe0f": "man police officer",
    "\U0001f46e\u200d\u2640\ufe0f": "woman police officer",
    "\U0001f575": "detective",
    "\U0001f575\ufe0f\u200d\u2642\ufe0f": "man detective",
    "\U0001f575\ufe0f\u200d\u2640\ufe0f": "woman detective",
    "\U0001f482": "guard",
    "\U0001f482\u200d\u2642\ufe0f": "man guard",
    "\U0001f482\u200d\u2640\ufe0f": "woman guard",
    "\U0001f977": "ninja",
    "\U0001f477": "construction worker",
    "\U0001f477\u200d\u2642\ufe0f": "man construction worker",
    "\U0001f477\u200d\u2640\ufe0f": "woman construction worker",
    "\U0001fac5": "person with crown",
    "\U0001f934": "prince",
    "\U0001f478": "princess",
    "\U0001f473": "person wearing turban",
    "\U0001f473\u200d\u2642\ufe0f": "man wearing turban",
    "\U0001f473\u200d\u2640\ufe0f": "woman wearing turban",
    "\U0001f472": "person with skullcap",
    "\U0001f9d5": "woman with headscarf",
    "\U0001f935": "person in tuxedo",
    "\U0001f935\u200d\u2642\ufe0f": "man in tuxedo",
    "\U0001f935\u200d\u2640\ufe0f": "woman in tuxedo",
    "\U0001f470": "person with veil",
    "\U0001f470\u200d\u2642\ufe0f": "man with veil",
    "\U0001f470\u200d\u2640\ufe0f": "woman with veil",
    "\U0001f930": "pregnant woman",
    "\U0001fac3": "pregnant man",
    "\U0001fac4": "pregnant person",
    "\U0001f931": "breast-feeding",
    "\U0001f469\u200d\U0001f37c": "woman feeding baby",
    "\U0001f468\u200d\U0001f37c": "man feeding baby",
    "\U0001f9d1\u200d\U0001f37c": "person feeding baby",
    # person-fantasy
    "\U0001f47c": "baby angel",
    "\U0001f385": "Santa Claus",
    "\U0001f936": "Mrs. Claus",
    "\U0001f9d1\u200d\U0001f384": "Mx Claus",
    "\U0001f9b8": "superhero",
    "\U0001f9b8\u200d\u2642\ufe0f": "man superhero",
    "\U0001f9b8\u200d\u2640\ufe0f": "woman superhero",
    "\U0001f9b9": "supervillain",
    "\U0001f9b9\u200d\u2642\ufe0f": "man supervillain",
    "\U0001f9b9\u200d\u2640\ufe0f": "woman supervillain",
    "\U0001f9d9": "mage",
    "\U0001f9d9\u200d\u2642\ufe0f": "man mage",
    "\U0001f9d9\u200d\u2640\ufe0f": "woman mage",
    "\U0001f9da": "fairy",
    "\U0001f9da\u200d\u2642\ufe0f": "man fairy",
    "\U0001f9da\u200d\u2640\ufe0f": "woman fairy",
    "\U0001f9db": "vampire",
    "\U0001f9db\u200d\u2642\ufe0f": "man vampire",
    "\U0001f9db\u200d\u2640\ufe0f": "woman vampire",
    "\U0001f9dc": "merperson",
    "\U0001f9dc\u200d\u2642\ufe0f": "merman",
    "\U0001f9dc\u200d\u2640\ufe0f": "mermaid",
    "\U0001f9dd": "elf",
    "\U0001f9dd\u200d\u2642\ufe0f": "man elf",
    "\U0001f9dd\u200d\u2640\ufe0f": "woman elf",
    "\U0001f9de": "genie",
    "\U0001f9de\u200d\u2642\ufe0f": "man genie",
    "\U0001f9de\u200d\u2640\ufe0f": "woman genie",
    "\U0001f9df": "zombie",
    "\U0001f9df\u200d\u2642\ufe0f": "man zombie",
    "\U0001f9df\u200d\u2640\ufe0f": "woman zombie",
    "\U0001f9cc": "troll",
    # person-activity
    "\U0001f486": "person getting massage",
    "\U0001f486\u200d\u2642\ufe0f": "man getting massage",
    "\U0001f486\u200d\u2640\ufe0f": "woman getting massage",
    "\U0001f487": "person getting haircut",
    "\U0001f487\u200d\u2642\ufe0f": "man getting haircut",
    "\U0001f487\u200d\u2640\ufe0f": "woman getting haircut",
    "\U0001f6b6": "person walking",
    "\U0001f6b6\u200d\u2642\ufe0f": "man walking",
    "\U0001f6b6\u200d\u2640\ufe0f": "woman walking",
    "\U0001f6b6\u200d\u27a1\ufe0f": "person walking facing right",
    "\U0001f6b6\u200d\u2640\ufe0f\u200d\u27a1\ufe0f": "woman walking facing right",
    "\U0001f6b6\u200d\u2642\ufe0f\u200d\u27a1\ufe0f": "man walking facing right",
    "\U0001f9cd": "person standing",
    "\U0001f9cd\u200d\u2642\ufe0f": "man standing",
    "\U0001f9cd\u200d\u2640\ufe0f": "woman standing",
    "\U0001f9ce": "person kneeling",
    "\U0001f9ce\u200d\u2642\ufe0f": "man kneeling",
    "\U0001f9ce\u200d\u2640\ufe0f": "woman kneeling",
    "\U0001f9ce\u200d\u27a1\ufe0f": "person kneeling facing right",
    "\U0001f9ce\u200d\u2640\ufe0f\u200d\u27a1\ufe0f": "woman kneeling facing right",
    "\U0001f9ce\u200d\u2642\ufe0f\u200d\u27a1\ufe0f": "man kneeling facing right",
    "\U0001f9d1\u200d\U0001f9af": "person with white cane",
    "\U0001f9d1\u200d\U0001f9af\u200d\u27a1\ufe0f": "person with white cane facing right",
    "\U0001f468\u200d\U0001f9af": "man with white cane",
    "\U0001f468\u200d\U0001f9af\u200d\u27a1\ufe0f": "man with white cane facing right",
    "\U0001f469\u200d\U0001f9af": "woman with white cane",
    "\U0001f469\u200d\U0001f9af\u200d\u27a1\ufe0f": "woman with white cane facing right",
    "\U0001f9d1\u200d\U0001f9bc": "person in motorized wheelchair",
    "\U0001f9d1\u200d\U0001f9bc\u200d\u27a1\ufe0f": "person in motorized wheelchair facing right",
    "\U0001f468\u200d\U0001f9bc": "man in motorized wheelchair",
    "\U0001f468\u200d\U0001f9bc\u200d\u27a1\ufe0f": "man in motorized wheelchair facing right",
    "\U0001f469\u200d\U0001f9bc": "woman in motorized wheelchair",
    "\U0001f469\u200d\U0001f9bc\u200d\u27a1\ufe0f": "woman in motorized wheelchair facing right",
    "\U0001f9d1\u200d\U0001f9bd": "person in manual wheelchair",
    "\U0001f9d1\u200d\U0001f9bd\u200d\u27a1\ufe0f": "person in manual wheelchair facing right",
    "\U0001f468\u200d\U0001f9bd": "man in manual wheelchair",
    "\U0001f468\u200d\U0001f9bd\u200d\u27a1\ufe0f": "man in manual wheelchair facing right",
    "\U0001f469\u200d\U0001f9bd": "woman in manual wheelchair",
    "\U0001f469\u200d\U0001f9bd\u200d\u27a1\ufe0f": "woman in manual wheelchair facing right",
    "\U0001f3c3": "person running",
    "\U0001f3c3\u200d\u2642\ufe0f": "man running",
    "\U0001f3c3\u200d\u2640\ufe0f": "woman running",
    "\U0001f3c3\u200d\u27a1\ufe0f": "person running facing right",
    "\U0001f3c3\u200d\u2640\ufe0f\u200d\u27a1\ufe0f": "woman running facing right",
    "\U0001f3c3\u200d\u2642\ufe0f\u200d\u27a1\ufe0f": "man running facing right",
    "\U0001f483": "woman dancing",
    "\U0001f57a": "man dancing",
    "\U0001f574": "person in suit levitating",
    "\U0001f46f": "people with bunny ears",
    "\U0001f46f\u200d\u2642\ufe0f": "men with bunny ears",
    "\U0001f46f\u200d\u2640\ufe0f": "women with bunny ears",
    "\U0001f9d6": "person in steamy room",
    "\U0001f9d6\u200d\u2642\ufe0f": "man in steamy room",
    "\U0001f9d6\u200d\u2640\ufe0f": "woman in steamy room",
    "\U0001f9d7": "person climbing",
    "\U0001f9d7\u200d\u2642\ufe0f": "man climbing",
    "\U0001f9d7\u200d\u2640\ufe0f": "woman climbing",
    # person-sport
    "\U0001f93a": "person fencing",
    "\U0001f3c7": "horse racing",
    "\u26f7": "skier",
    "\U0001f3c2": "snowboarder",
    "\U0001f3cc": "person golfing",
    "\U0001f3cc\ufe0f\u200d\u2642\ufe0f": "man golfing",
    "\U0001f3cc\ufe0f\u200d\u2640\ufe0f": "woman golfing",
    "\U0001f3c4": "person surfing",
    "\U0001f3c4\u200d\u2642\ufe0f": "man surfing",
    "\U0001f3c4\u200d\u2640\ufe0f": "woman surfing",
    "\U0001f6a3": "person rowing boat",
    "\U0001f6a3\u200d\u2642\ufe0f": "man rowing boat",
    "\U0001f6a3\u200d\u2640\ufe0f": "woman rowing boat",
    "\U0001f3ca": "person swimming",
    "\U0001f3ca\u200d\u2642\ufe0f": "man swimming",
    "\U0001f3ca\u200d\u2640\ufe0f": "woman swimming",
    "\u26f9": "person bouncing ball",
    "\u26f9\ufe0f\u200d\u2642\ufe0f": "man bouncing ball",
    "\u26f9\ufe0f\u200d\u2640\ufe0f": "woman bouncing ball",
    "\U0001f3cb": "person lifting weights",
    "\U0001f3cb\ufe0f\u200d\u2642\ufe0f": "man lifting weights",
    "\U0001f3cb\ufe0f\u200d\u2640\ufe0f": "woman lifting weights",
    "\U0001f6b4": "person biking",
    "\U0001f6b4\u200d\u2642\ufe0f": "man biking",
    "\U0001f6b4\u200d\u2640\ufe0f": "woman biking",
    "\U0001f6b5": "person mountain biking",
    "\U0001f6b5\u200d\u2642\ufe0f": "man mountain biking",
    "\U0001f6b5\u200d\u2640\ufe0f": "woman mountain biking",
    "\U0001f938": "person cartwheeling",
    "\U0001f938\u200d\u2642\ufe0f": "man cartwheeling",
    "\U0001f938\u200d\u2640\ufe0f": "woman cartwheeling",
    "\U0001f93c": "people wrestling",
    "\U0001f93c\u200d\u2642\ufe0f": "men wrestling",
    "\U0001f93c\u200d\u2640\ufe0f": "women wrestling",
    "\U0001f93d": "person playing water polo",
    "\U0001f93d\u200d\u2642\ufe0f": "man playing water polo",
    "\U0001f93d\u200d\u2640\ufe0f": "woman playing water polo",
    "\U0001f93e": "person playing handball",
    "\U0001f93e\u200d\u2642\ufe0f": "man playing handball",
    "\U0001f93e\u200d\u2640\ufe0f": "woman playing handball",
    "\U0001f939": "person juggling",
    "\U0001f939\u200d\u2642\ufe0f": "man juggling",
    "\U0001f939\u200d\u2640\ufe0f": "woman juggling",
    # person-resting
    "\U0001f9d8": "person in lotus position",
    "\U0001f9d8\u200d\u2642\ufe0f": "man in lotus position",
    "\U0001f9d8\u200d\u2640\ufe0f": "woman in lotus position",
    "\U0001f6c0": "person taking bath",
    "\U0001f6cc": "person in bed",
    # family
    "\U0001f9d1\u200d\U0001f91d\u200d\U0001f9d1": "people holding hands",
    "\U0001f46d": "women holding hands",
    "\U0001f46b": "woman and man holding hands",
    "\U0001f46c": "men holding hands",
    "\U0001f48f": "kiss",
    "\U0001f469\u200d\u2764\ufe0f\u200d\U0001f48b\u200d\U0001f468": "kiss: woman, man",
    "\U0001f468\u200d\u2764\ufe0f\u200d\U0001f48b\u200d\U0001f468": "kiss: man, man",
    "\U0001f469\u200d\u2764\ufe0f\u200d\U0001f48b\u200d\U0001f469": "kiss: woman, woman",
    "\U0001f491": "couple with heart",
    "\U0001f469\u200d\u2764\ufe0f\u200d\U0001f468": "couple with heart: woman, man",
    "\U0001f468\u200d\u2764\ufe0f\u200d\U0001f468": "couple with heart: man, man",
    "\U0001f469\u200d\u2764\ufe0f\u200d\U0001f469": "couple with heart: woman, woman",
    "\U0001f468\u200d\U0001f469\u200d\U0001f466": "family: man, woman, boy",
    "\U0001f468\u200d\U0001f469\u200d\U0001f467": "family: man, woman, girl",
    "\U0001f468\u200d\U0001f469\u200d\U0001f467\u200d\U0001f466": "family: man, woman, girl, boy",
    "\U0001f468\u200d\U0001f469\u200d\U0001f466\u200d\U0001f466": "family: man, woman, boy, boy",
    "\U0001f468\u200d\U0001f469\u200d\U0001f467\u200d\U0001f467": "family: man, woman, girl, girl",
    "\U0001f468\u200d\U0001f468\u200d\U0001f466": "family: man, man, boy",
    "\U0001f468\u200d\U0001f468\u200d\U0001f467": "family: man, man, girl",
    "\U0001f468\u200d\U0001f468\u200d\U0001f467\u200d\U0001f466": "family: man, man, girl, boy",
    "\U0001f468\u200d\U0001f468\u200d\U0001f466\u200d\U0001f466": "family: man, man, boy, boy",
    "\U0001f468\u200d\U0001f468\u200d\U0001f467\u200d\U0001f467": "family: man, man, girl, girl",
    "\U0001f469\u200d\U0001f469\u200d\U0001f466": "family: woman, woman, boy",
    "\U0001f469\u200d\U0001f469\u200d\U0001f467": "family: woman, woman, girl",
    "\U0001f469\u200d\U0001f469\u200d\U0001f467\u200d\U0001f466": "family: woman, woman, girl, boy",
    "\U0001f469\u200d\U0001f469\u200d\U0001f466\u200d\U0001f466": "family: woman, woman, boy, boy",
    "\U0001f469\u200d\U0001f469\u200d\U0001f467\u200d\U0001f467": "family: woman, woman, girl, girl",
    "\U0001f468\u200d\U0001f466": "family: man, boy",
    "\U0001f468\u200d\U0001f466\u200d\U0001f466": "family: man, boy, boy",
    "\U0001f468\u200d\U0001f467": "family: man, girl",
    "\U0001f468\u200d\U0001f467\u200d\U0001f466": "family: man, girl, boy",
    "\U0001f468\u200d\U0001f467\u200d\U0001f467": "family: man, girl, girl",
    "\U0001f469\u200d\U0001f466": "family: woman, boy",
    "\U0001f469\u200d\U0001f466\u200d\U0001f466": "family: woman, boy, boy",
    "\U0001f469\u200d\U0001f467": "family: woman, girl",
    "\U0001f469\u200d\U0001f467\u200d\U0001f466": "family: woman, girl, boy",
    "\U0001f469\u200d\U0001f467\u200d\U0001f467": "family: woman, girl, girl",
    # person-symbol
    "\U0001f5e3": "speaking head",
    "\U0001f464": "bust in silhouette",
    "\U0001f465": "busts in silhouette",
    "\U0001fac2": "people hugging",
    "\U0001f46a": "family",
    "\U0001f9d1\u200d\U0001f9d1\u200d\U0001f9d2": "family: adult, adult, child",
    "\U0001f9d1\u200d\U0001f9d1\u200d\U0001f9d2\u200d\U0001f9d2": "family: adult, adult, child, child",
    "\U0001f9d1\u200d\U0001f9d2": "family: adult, child",
    "\U0001f9d1\u200d\U0001f9d2\u200d\U0001f9d2": "family: adult, child, child",
    "\U0001f463": "footprints",
    "\U0001fac6": "fingerprint",
    # Component
    # hair-style
    "\U0001f9b0": "red hair",
    "\U0001f9b1": "curly hair",
    "\U0001f9b3": "white hair",
    "\U0001f9b2": "bald",
    # Animals & Nature
    # animal-mammal
    "\U0001f435": "monkey face",
    "\U0001f412": "monkey",
    "\U0001f98d": "gorilla",
    "\U0001f9a7": "orangutan",
    "\U0001f436": "dog face",
    "\U0001f415": "dog",
    "\U0001f9ae": "guide dog",
    "\U0001f415\u200d\U0001f9ba": "service dog",
    "\U0001f429": "poodle",
    "\U0001f43a": "wolf",
    "\U0001f98a": "fox",
    "\U0001f99d": "raccoon",
    "\U0001f431": "cat face",
    "\U0001f408": "cat",
    "\U0001f408\u200d\u2b1b": "black cat",
    "\U0001f981": "lion",
    "\U0001f42f": "tiger face",
    "\U0001f405": "tiger",
    "\U0001f406": "leopard",
    "\U0001f434": "horse face",
    "\U0001face": "moose",
    "\U0001facf": "donkey",
    "\U0001f40e": "horse",
    "\U0001f984": "unicorn",
    "\U0001f993": "zebra",
    "\U0001f98c": "deer",
    "\U0001f9ac": "bison",
    "\U0001f42e": "cow face",
    "\U0001f402": "ox",
    "\U0001f403": "water buffalo",
    "\U0001f404": "cow",
    "\U0001f437": "pig face",
    "\U0001f416": "pig",
    "\U0001f417": "boar",
    "\U0001f43d": "pig nose",
    "\U0001f40f": "ram",
    "\U0001f411": "ewe",
    "\U0001f410": "goat",
    "\U0001f42a": "camel",
    "\U0001f42b": "two-hump camel",
    "\U0001f999": "llama",
    "\U0001f992": "giraffe",
    "\U0001f418": "elephant",
    "\U0001f9a3": "mammoth",
    "\U0001f98f": "rhinoceros",
    "\U0001f99b": "hippopotamus",
    "\U0001f42d": "mouse face",
    "\U0001f401": "mouse",
    "\U0001f400": "rat",
    "\U0001f439": "hamster",
    "\U0001f430": "rabbit face",
    "\U0001f407": "rabbit",
    "\U0001f43f": "chipmunk",
    "\U0001f9ab": "beaver",
    "\U0001f994": "hedgehog",
    "\U0001f987": "bat",
    "\U0001f43b": "bear",
    "\U0001f43b\u200d\u2744\ufe0f": "polar bear",
    "\U0001f428": "koala",
    "\U0001f43c": "panda",
    "\U0001f9a5": "sloth",
    "\U0001f9a6": "otter",
    "\U0001f9a8": "skunk",
    "\U0001f998": "kangaroo",
    "\U0001f9a1": "badger",
    "\U0001f43e": "paw prints",
    # animal-bird
    "\U0001f983": "turkey",
    "\U0001f414": "chicken",
    "\U0001f413": "rooster",
    "\U0001f423": "hatching chick",
    "\U0001f424": "baby chick",
    "\U0001f425": "front-facing baby chick",
    "\U0001f426": "bird",
    "\U0001f427": "penguin",
    "\U0001f54a": "dove",
    "\U0001f985": "eagle",
    "\U0001f986": "duck",
    "\U0001f9a2": "swan",
    "\U0001f989": "owl",
    "\U0001f9a4": "dodo",
    "\U0001fab6": "feather",
    "\U0001f9a9": "flamingo",
    "\U0001f99a": "peacock",
    "\U0001f99c": "parrot",
    "\U0001fabd": "wing",
    "\U0001f426\u200d\u2b1b": "black bird",
    "\U0001fabf": "goose",
    "\U0001f426\u200d\U0001f525": "phoenix",
    # animal-amphibian
    "\U0001f438": "frog",
    # animal-reptile
    "\U0001f40a": "crocodile",
    "\U0001f422": "turtle",
    "\U0001f98e": "lizard",
    "\U0001f40d": "snake",
    "\U0001f432": "dragon face",
    "\U0001f409": "dragon",
    "\U0001f995": "sauropod",
    "\U0001f996": "T-Rex",
    # animal-marine
    "\U0001f433": "spouting whale",
    "\U0001f40b": "whale",
    "\U0001f42c": "dolphin",
    "\U0001f9ad": "seal",
    "\U0001f41f": "fish",
    "\U0001f420": "tropical fish",
    "\U0001f421": "blowfish",
    "\U0001f988": "shark",
    "\U0001f419": "octopus",
    "\U0001f41a": "spiral shell",
    "\U0001fab8": "coral",
    "\U0001fabc": "jellyfish",
    "\U0001f980": "crab",
    "\U0001f99e": "lobster",
    "\U0001f990": "shrimp",
    "\U0001f991": "squid",
    "\U0001f9aa": "oyster",
    # animal-bug
    "\U0001f40c": "snail",
    "\U0001f98b": "butterfly",
    "\U0001f41b": "bug",
    "\U0001f41c": "ant",
    "\U0001f41d": "honeybee",
    "\U0001fab2": "beetle",
    "\U0001f41e": "lady beetle",
    "\U0001f997": "cricket",
    "\U0001fab3": "cockroach",
    "\U0001f577": "spider",
    "\U0001f578": "spider web",
    "\U0001f982": "scorpion",
    "\U0001f99f": "mosquito",
    "\U0001fab0": "fly",
    "\U0001fab1": "worm",
    "\U0001f9a0": "microbe",
    # plant-flower
    "\U0001f490": "bouquet",
    "\U0001f338": "cherry blossom",
    "\U0001f4ae": "white flower",
    "\U0001fab7": "lotus",
    "\U0001f3f5": "rosette",
    "\U0001f339": "rose",
    "\U0001f940": "wilted flower",
    "\U0001f33a": "hibiscus",
    "\U0001f33b": "sunflower",
    "\U0001f33c": "blossom",
    "\U0001f337": "tulip",
    "\U0001fabb": "hyacinth",
    # plant-other
    "\U0001f331": "seedling",
    "\U0001fab4": "potted plant",
    "\U0001f332": "evergreen tree",
    "\U0001f333": "deciduous tree",
    "\U0001f334": "palm tree",
    "\U0001f335": "cactus",
    "\U0001f33e": "sheaf of rice",
    "\U0001f33f": "herb",
    "\u2618": "shamrock",
    "\U0001f340": "four leaf clover",
    "\U0001f341": "maple leaf",
    "\U0001f342": "fallen leaf",
    "\U0001f343": "leaf fluttering in wind",
    "\U0001fab9": "empty nest",
    "\U0001faba": "nest with eggs",
    "\U0001f344": "mushroom",
    "\U0001fabe": "⊛ leafless tree",
    # Food & Drink
    # food-fruit
    "\U0001f347": "grapes",
    "\U0001f348": "melon",
    "\U0001f349": "watermelon",
    "\U0001f34a": "tangerine",
    "\U0001f34b": "lemon",
    "\U0001f34b\u200d\U0001f7e9": "lime",
    "\U0001f34c": "banana",
    "\U0001f34d": "pineapple",
    "\U0001f96d": "mango",
    "\U0001f34e": "red apple",
    "\U0001f34f": "green apple",
    "\U0001f350": "pear",
    "\U0001f351": "peach",
    "\U0001f352": "cherries",
    "\U0001f353": "strawberry",
    "\U0001fad0": "blueberries",
    "\U0001f95d": "kiwi fruit",
    "\U0001f345": "tomato",
    "\U0001fad2": "olive",
    "\U0001f965": "coconut",
    # food-vegetable
    "\U0001f951": "avocado",
    "\U0001f346": "eggplant",
    "\U0001f954": "potato",
    "\U0001f955": "carrot",
    "\U0001f33d": "ear of corn",
    "\U0001f336": "hot pepper",
    "\U0001fad1": "bell pepper",
    "\U0001f952": "cucumber",
    "\U0001f96c": "leafy green",
    "\U0001f966": "broccoli",
    "\U0001f9c4": "garlic",
    "\U0001f9c5": "onion",
    "\U0001f95c": "peanuts",
    "\U0001fad8": "beans",
    "\U0001f330": "chestnut",
    "\U0001fada": "ginger root",
    "\U0001fadb": "pea pod",
    "\U0001f344\u200d\U0001f7eb": "brown mushroom",
    "\U0001fadc": "⊛ root vegetable",
    # food-prepared
    "\U0001f35e": "bread",
    "\U0001f950": "croissant",
    "\U0001f956": "baguette bread",
    "\U0001fad3": "flatbread",
    "\U0001f968": "pretzel",
    "\U0001f96f": "bagel",
    "\U0001f95e": "pancakes",
    "\U0001f9c7": "waffle",
    "\U0001f9c0": "cheese wedge",
    "\U0001f356": "meat on bone",
    "\U0001f357": "poultry leg",
    "\U0001f969": "cut of meat",
    "\U0001f953": "bacon",
    "\U0001f354": "hamburger",
    "\U0001f35f": "french fries",
    "\U0001f355": "pizza",
    "\U0001f32d": "hot dog",
    "\U0001f96a": "sandwich",
    "\U0001f32e": "taco",
    "\U0001f32f": "burrito",
    "\U0001fad4": "tamale",
    "\U0001f959": "stuffed flatbread",
    "\U0001f9c6": "falafel",
    "\U0001f95a": "egg",
    "\U0001f373": "cooking",
    "\U0001f958": "shallow pan of food",
    "\U0001f372": "pot of food",
    "\U0001fad5": "fondue",
    "\U0001f963": "bowl with spoon",
    "\U0001f957": "green salad",
    "\U0001f37f": "popcorn",
    "\U0001f9c8": "butter",
    "\U0001f9c2": "salt",
    "\U0001f96b": "canned food",
    # food-asian
    "\U0001f371": "bento box",
    "\U0001f358": "rice cracker",
    "\U0001f359": "rice ball",
    "\U0001f35a": "cooked rice",
    "\U0001f35b": "curry rice",
    "\U0001f35c": "steaming bowl",
    "\U0001f35d": "spaghetti",
    "\U0001f360": "roasted sweet potato",
    "\U0001f362": "oden",
    "\U0001f363": "sushi",
    "\U0001f364": "fried shrimp",
    "\U0001f365": "fish cake with swirl",
    "\U0001f96e": "moon cake",
    "\U0001f361": "dango",
    "\U0001f95f": "dumpling",
    "\U0001f960": "fortune cookie",
    "\U0001f961": "takeout box",
    # food-sweet
    "\U0001f366": "soft ice cream",
    "\U0001f367": "shaved ice",
    "\U0001f368": "ice cream",
    "\U0001f369": "doughnut",
    "\U0001f36a": "cookie",
    "\U0001f382": "birthday cake",
    "\U0001f370": "shortcake",
    "\U0001f9c1": "cupcake",
    "\U0001f967": "pie",
    "\U0001f36b": "chocolate bar",
    "\U0001f36c": "candy",
    "\U0001f36d": "lollipop",
    "\U0001f36e": "custard",
    "\U0001f36f": "honey pot",
    # drink
    "\U0001f37c": "baby bottle",
    "\U0001f95b": "glass of milk",
    "\u2615": "hot beverage",
    "\U0001fad6": "teapot",
    "\U0001f375": "teacup without handle",
    "\U0001f376": "sake",
    "\U0001f37e": "bottle with popping cork",
    "\U0001f377": "wine glass",
    "\U0001f378": "cocktail glass",
    "\U0001f379": "tropical drink",
    "\U0001f37a": "beer mug",
    "\U0001f37b": "clinking beer mugs",
    "\U0001f942": "clinking glasses",
    "\U0001f943": "tumbler glass",
    "\U0001fad7": "pouring liquid",
    "\U0001f964": "cup with straw",
    "\U0001f9cb": "bubble tea",
    "\U0001f9c3": "beverage box",
    "\U0001f9c9": "mate",
    "\U0001f9ca": "ice",
    # dishware
    "\U0001f962": "chopsticks",
    "\U0001f37d": "fork and knife with plate",
    "\U0001f374": "fork and knife",
    "\U0001f944": "spoon",
    "\U0001f52a": "kitchen knife",
    "\U0001fad9": "jar",
    "\U0001f3fa": "amphora",
    # Travel & Places
    # place-map
    "\U0001f30d": "globe showing Europe-Africa",
    "\U0001f30e": "globe showing Americas",
    "\U0001f30f": "globe showing Asia-Australia",
    "\U0001f310": "globe with meridians",
    "\U0001f5fa": "world map",
    "\U0001f5fe": "map of Japan",
    "\U0001f9ed": "compass",
    # place-geographic
    "\U0001f3d4": "snow-capped mountain",
    "\u26f0": "mountain",
    "\U0001f30b": "volcano",
    "\U0001f5fb": "mount fuji",
    "\U0001f3d5": "camping",
    "\U0001f3d6": "beach with umbrella",
    "\U0001f3dc": "desert",
    "\U0001f3dd": "desert island",
    "\U0001f3de": "national park",
    # place-building
    "\U0001f3df": "stadium",
    "\U0001f3db": "classical building",
    "\U0001f3d7": "building construction",
    "\U0001f9f1": "brick",
    "\U0001faa8": "rock",
    "\U0001fab5": "wood",
    "\U0001f6d6": "hut",
    "\U0001f3d8": "houses",
    "\U0001f3da": "derelict house",
    "\U0001f3e0": "house",
    "\U0001f3e1": "house with garden",
    "\U0001f3e2": "office building",
    "\U0001f3e3": "Japanese post office",
    "\U0001f3e4": "post office",
    "\U0001f3e5": "hospital",
    "\U0001f3e6": "bank",
    "\U0001f3e8": "hotel",
    "\U0001f3e9": "love hotel",
    "\U0001f3ea": "convenience store",
    "\U0001f3eb": "school",
    "\U0001f3ec": "department store",
    "\U0001f3ed": "factory",
    "\U0001f3ef": "Japanese castle",
    "\U0001f3f0": "castle",
    "\U0001f492": "wedding",
    "\U0001f5fc": "Tokyo tower",
    "\U0001f5fd": "Statue of Liberty",
    # place-religious
    "\u26ea": "church",
    "\U0001f54c": "mosque",
    "\U0001f6d5": "hindu temple",
    "\U0001f54d": "synagogue",
    "\u26e9": "shinto shrine",
    "\U0001f54b": "kaaba",
    # place-other
    "\u26f2": "fountain",
    "\u26fa": "tent",
    "\U0001f301": "foggy",
    "\U0001f303": "night with stars",
    "\U0001f3d9": "cityscape",
    "\U0001f304": "sunrise over mountains",
    "\U0001f305": "sunrise",
    "\U0001f306": "cityscape at dusk",
    "\U0001f307": "sunset",
    "\U0001f309": "bridge at night",
    "\u2668": "hot springs",
    "\U0001f3a0": "carousel horse",
    "\U0001f6dd": "playground slide",
    "\U0001f3a1": "ferris wheel",
    "\U0001f3a2": "roller coaster",
    "\U0001f488": "barber pole",
    "\U0001f3aa": "circus tent",
    # transport-ground
    "\U0001f682": "locomotive",
    "\U0001f683": "railway car",
    "\U0001f684": "high-speed train",
    "\U0001f685": "bullet train",
    "\U0001f686": "train",
    "\U0001f687": "metro",
    "\U0001f688": "light rail",
    "\U0001f689": "station",
    "\U0001f68a": "tram",
    "\U0001f69d": "monorail",
    "\U0001f69e": "mountain railway",
    "\U0001f68b": "tram car",
    "\U0001f68c": "bus",
    "\U0001f68d": "oncoming bus",
    "\U0001f68e": "trolleybus",
    "\U0001f690": "minibus",
    "\U0001f691": "ambulance",
    "\U0001f692": "fire engine",
    "\U0001f693": "police car",
    "\U0001f694": "oncoming police car",
    "\U0001f695": "taxi",
    "\U0001f696": "oncoming taxi",
    "\U0001f697": "automobile",
    "\U0001f698": "oncoming automobile",
    "\U0001f699": "sport utility vehicle",
    "\U0001f6fb": "pickup truck",
    "\U0001f69a": "delivery truck",
    "\U0001f69b": "articulated lorry",
    "\U0001f69c": "tractor",
    "\U0001f3ce": "racing car",
    "\U0001f3cd": "motorcycle",
    "\U0001f6f5": "motor scooter",
    "\U0001f9bd": "manual wheelchair",
    "\U0001f9bc": "motorized wheelchair",
    "\U0001f6fa": "auto rickshaw",
    "\U0001f6b2": "bicycle",
    "\U0001f6f4": "kick scooter",
    "\U0001f6f9": "skateboard",
    "\U0001f6fc": "roller skate",
    "\U0001f68f": "bus stop",
    "\U0001f6e3": "motorway",
    "\U0001f6e4": "railway track",
    "\U0001f6e2": "oil drum",
    "\u26fd": "fuel pump",
    "\U0001f6de": "wheel",
    "\U0001f6a8": "police car light",
    "\U0001f6a5": "horizontal traffic light",
    "\U0001f6a6": "vertical traffic light",
    "\U0001f6d1": "stop sign",
    "\U0001f6a7": "construction",
    # transport-water
    "\u2693": "anchor",
    "\U0001f6df": "ring buoy",
    "\u26f5": "sailboat",
    "\U0001f6f6": "canoe",
    "\U0001f6a4": "speedboat",
    "\U0001f6f3": "passenger ship",
    "\u26f4": "ferry",
    "\U0001f6e5": "motor boat",
    "\U0001f6a2": "ship",
    # transport-air
    "\u2708": "airplane",
    "\U0001f6e9": "small airplane",
    "\U0001f6eb": "airplane departure",
    "\U0001f6ec": "airplane arrival",
    "\U0001fa82": "parachute",
    "\U0001f4ba": "seat",
    "\U0001f681": "helicopter",
    "\U0001f69f": "suspension railway",
    "\U0001f6a0": "mountain cableway",
    "\U0001f6a1": "aerial tramway",
    "\U0001f6f0": "satellite",
    "\U0001f680": "rocket",
    "\U0001f6f8": "flying saucer",
    # hotel
    "\U0001f6ce": "bellhop bell",
    "\U0001f9f3": "luggage",
    # time
    "\u231b": "hourglass done",
    "\u23f3": "hourglass not done",
    "\u231a": "watch",
    "\u23f0": "alarm clock",
    "\u23f1": "stopwatch",
    "\u23f2": "timer clock",
    "\U0001f570": "mantelpiece clock",
    "\U0001f55b": "twelve o’clock",
    "\U0001f567": "twelve-thirty",
    "\U0001f550": "one o’clock",
    "\U0001f55c": "one-thirty",
    "\U0001f551": "two o’clock",
    "\U0001f55d": "two-thirty",
    "\U0001f552": "three o’clock",
    "\U0001f55e": "three-thirty",
    "\U0001f553": "four o’clock",
    "\U0001f55f": "four-thirty",
    "\U0001f554": "five o’clock",
    "\U0001f560": "five-thirty",
    "\U0001f555": "six o’clock",
    "\U0001f561": "six-thirty",
    "\U0001f556": "seven o’clock",
    "\U0001f562": "seven-thirty",
    "\U0001f557": "eight o’clock",
    "\U0001f563": "eight-thirty",
    "\U0001f558": "nine o’clock",
    "\U0001f564": "nine-thirty",
    "\U0001f559": "ten o’clock",
    "\U0001f565": "ten-thirty",
    "\U0001f55a": "eleven o’clock",
    "\U0001f566": "eleven-thirty",
    # sky & weather
    "\U0001f311": "new moon",
    "\U0001f312": "waxing crescent moon",
    "\U0001f313": "first quarter moon",
    "\U0001f314": "waxing gibbous moon",
    "\U0001f315": "full moon",
    "\U0001f316": "waning gibbous moon",
    "\U0001f317": "last quarter moon",
    "\U0001f318": "waning crescent moon",
    "\U0001f319": "crescent moon",
    "\U0001f31a": "new moon face",
    "\U0001f31b": "first quarter moon face",
    "\U0001f31c": "last quarter moon face",
    "\U0001f321": "thermometer",
    "\u2600": "sun",
    "\U0001f31d": "full moon face",
    "\U0001f31e": "sun with face",
    "\U0001fa90": "ringed planet",
    "\u2b50": "star",
    "\U0001f31f": "glowing star",
    "\U0001f320": "shooting star",
    "\U0001f30c": "milky way",
    "\u2601": "cloud",
    "\u26c5": "sun behind cloud",
    "\u26c8": "cloud with lightning and rain",
    "\U0001f324": "sun behind small cloud",
    "\U0001f325": "sun behind large cloud",
    "\U0001f326": "sun behind rain cloud",
    "\U0001f327": "cloud with rain",
    "\U0001f328": "cloud with snow",
    "\U0001f329": "cloud with lightning",
    "\U0001f32a": "tornado",
    "\U0001f32b": "fog",
    "\U0001f32c": "wind face",
    "\U0001f300": "cyclone",
    "\U0001f308": "rainbow",
    "\U0001f302": "closed umbrella",
    "\u2602": "umbrella",
    "\u2614": "umbrella with rain drops",
    "\u26f1": "umbrella on ground",
    "\u26a1": "high voltage",
    "\u2744": "snowflake",
    "\u2603": "snowman",
    "\u26c4": "snowman without snow",
    "\u2604": "comet",
    "\U0001f525": "fire",
    "\U0001f4a7": "droplet",
    "\U0001f30a": "water wave",
    # Activities
    # event
    "\U0001f383": "jack-o-lantern",
    "\U0001f384": "Christmas tree",
    "\U0001f386": "fireworks",
    "\U0001f387": "sparkler",
    "\U0001f9e8": "firecracker",
    "\u2728": "sparkles",
    "\U0001f388": "balloon",
    "\U0001f389": "party popper",
    "\U0001f38a": "confetti ball",
    "\U0001f38b": "tanabata tree",
    "\U0001f38d": "pine decoration",
    "\U0001f38e": "Japanese dolls",
    "\U0001f38f": "carp streamer",
    "\U0001f390": "wind chime",
    "\U0001f391": "moon viewing ceremony",
    "\U0001f9e7": "red envelope",
    "\U0001f380": "ribbon",
    "\U0001f381": "wrapped gift",
    "\U0001f397": "reminder ribbon",
    "\U0001f39f": "admission tickets",
    "\U0001f3ab": "ticket",
    # award-medal
    "\U0001f396": "military medal",
    "\U0001f3c6": "trophy",
    "\U0001f3c5": "sports medal",
    "\U0001f947": "1st place medal",
    "\U0001f948": "2nd place medal",
    "\U0001f949": "3rd place medal",
    # sport
    "\u26bd": "soccer ball",
    "\u26be": "baseball",
    "\U0001f94e": "softball",
    "\U0001f3c0": "basketball",
    "\U0001f3d0": "volleyball",
    "\U0001f3c8": "american football",
    "\U0001f3c9": "rugby football",
    "\U0001f3be": "tennis",
    "\U0001f94f": "flying disc",
    "\U0001f3b3": "bowling",
    "\U0001f3cf": "cricket game",
    "\U0001f3d1": "field hockey",
    "\U0001f3d2": "ice hockey",
    "\U0001f94d": "lacrosse",
    "\U0001f3d3": "ping pong",
    "\U0001f3f8": "badminton",
    "\U0001f94a": "boxing glove",
    "\U0001f94b": "martial arts uniform",
    "\U0001f945": "goal net",
    "\u26f3": "flag in hole",
    "\u26f8": "ice skate",
    "\U0001f3a3": "fishing pole",
    "\U0001f93f": "diving mask",
    "\U0001f3bd": "running shirt",
    "\U0001f3bf": "skis",
    "\U0001f6f7": "sled",
    "\U0001f94c": "curling stone",
    # game
    "\U0001f3af": "bullseye",
    "\U0001fa80": "yo-yo",
    "\U0001fa81": "kite",
    "\U0001f52b": "water pistol",
    "\U0001f3b1": "pool 8 ball",
    "\U0001f52e": "crystal ball",
    "\U0001fa84": "magic wand",
    "\U0001f3ae": "video game",
    "\U0001f579": "joystick",
    "\U0001f3b0": "slot machine",
    "\U0001f3b2": "game die",
    "\U0001f9e9": "puzzle piece",
    "\U0001f9f8": "teddy bear",
    "\U0001fa85": "pinata",
    "\U0001faa9": "mirror ball",
    "\U0001fa86": "nesting dolls",
    "\u2660": "spade suit",
    "\u2665": "heart suit",
    "\u2666": "diamond suit",
    "\u2663": "club suit",
    "\u265f": "chess pawn",
    "\U0001f0cf": "joker",
    "\U0001f004": "mahjong red dragon",
    "\U0001f3b4": "flower playing cards",
    # arts & crafts
    "\U0001f3ad": "performing arts",
    "\U0001f5bc": "framed picture",
    "\U0001f3a8": "artist palette",
    "\U0001f9f5": "thread",
    "\U0001faa1": "sewing needle",
    "\U0001f9f6": "yarn",
    "\U0001faa2": "knot",
    # Objects
    # clothing
    "\U0001f453": "glasses",
    "\U0001f576": "sunglasses",
    "\U0001f97d": "goggles",
    "\U0001f97c": "lab coat",
    "\U0001f9ba": "safety vest",
    "\U0001f454": "necktie",
    "\U0001f455": "t-shirt",
    "\U0001f456": "jeans",
    "\U0001f9e3": "scarf",
    "\U0001f9e4": "gloves",
    "\U0001f9e5": "coat",
    "\U0001f9e6": "socks",
    "\U0001f457": "dress",
    "\U0001f458": "kimono",
    "\U0001f97b": "sari",
    "\U0001fa71": "one-piece swimsuit",
    "\U0001fa72": "briefs",
    "\U0001fa73": "shorts",
    "\U0001f459": "bikini",
    "\U0001f45a": "woman’s clothes",
    "\U0001faad": "folding hand fan",
    "\U0001f45b": "purse",
    "\U0001f45c": "handbag",
    "\U0001f45d": "clutch bag",
    "\U0001f6cd": "shopping bags",
    "\U0001f392": "backpack",
    "\U0001fa74": "thong sandal",
    "\U0001f45e": "man’s shoe",
    "\U0001f45f": "running shoe",
    "\U0001f97e": "hiking boot",
    "\U0001f97f": "flat shoe",
    "\U0001f460": "high-heeled shoe",
    "\U0001f461": "woman’s sandal",
    "\U0001fa70": "ballet shoes",
    "\U0001f462": "woman’s boot",
    "\U0001faae": "hair pick",
    "\U0001f451": "crown",
    "\U0001f452": "woman’s hat",
    "\U0001f3a9": "top hat",
    "\U0001f393": "graduation cap",
    "\U0001f9e2": "billed cap",
    "\U0001fa96": "military helmet",
    "\u26d1": "rescue worker’s helmet",
    "\U0001f4ff": "prayer beads",
    "\U0001f484": "lipstick",
    "\U0001f48d": "ring",
    "\U0001f48e": "gem stone",
    # sound
    "\U0001f507": "muted speaker",
    "\U0001f508": "speaker low volume",
    "\U0001f509": "speaker medium volume",
    "\U0001f50a": "speaker high volume",
    "\U0001f4e2": "loudspeaker",
    "\U0001f4e3": "megaphone",
    "\U0001f4ef": "postal horn",
    "\U0001f514": "bell",
    "\U0001f515": "bell with slash",
    # music
    "\U0001f3bc": "musical score",
    "\U0001f3b5": "musical note",
    "\U0001f3b6": "musical notes",
    "\U0001f399": "studio microphone",
    "\U0001f39a": "level slider",
    "\U0001f39b": "control knobs",
    "\U0001f3a4": "microphone",
    "\U0001f3a7": "headphone",
    "\U0001f4fb": "radio",
    # musical-instrument
    "\U0001f3b7": "saxophone",
    "\U0001fa97": "accordion",
    "\U0001f3b8": "guitar",
    "\U0001f3b9": "musical keyboard",
    "\U0001f3ba": "trumpet",
    "\U0001f3bb": "violin",
    "\U0001fa95": "banjo",
    "\U0001f941": "drum",
    "\U0001fa98": "long drum",
    "\U0001fa87": "maracas",
    "\U0001fa88": "flute",
    "\U0001fa89": "⊛ harp",
    # phone
    "\U0001f4f1": "mobile phone",
    "\U0001f4f2": "mobile phone with arrow",
    "\u260e": "telephone",
    "\U0001f4de": "telephone receiver",
    "\U0001f4df": "pager",
    "\U0001f4e0": "fax machine",
    # computer
    "\U0001f50b": "battery",
    "\U0001faab": "low battery",
    "\U0001f50c": "electric plug",
    "\U0001f4bb": "laptop",
    "\U0001f5a5": "desktop computer",
    "\U0001f5a8": "printer",
    "\u2328": "keyboard",
    "\U0001f5b1": "computer mouse",
    "\U0001f5b2": "trackball",
    "\U0001f4bd": "computer disk",
    "\U0001f4be": "floppy disk",
    "\U0001f4bf": "optical disk",
    "\U0001f4c0": "dvd",
    "\U0001f9ee": "abacus",
    # light & video
    "\U0001f3a5": "movie camera",
    "\U0001f39e": "film frames",
    "\U0001f4fd": "film projector",
    "\U0001f3ac": "clapper board",
    "\U0001f4fa": "television",
    "\U0001f4f7": "camera",
    "\U0001f4f8": "camera with flash",
    "\U0001f4f9": "video camera",
    "\U0001f4fc": "videocassette",
    "\U0001f50d": "magnifying glass tilted left",
    "\U0001f50e": "magnifying glass tilted right",
    "\U0001f56f": "candle",
    "\U0001f4a1": "light bulb",
    "\U0001f526": "flashlight",
    "\U0001f3ee": "red paper lantern",
    "\U0001fa94": "diya lamp",
    # book-paper
    "\U0001f4d4": "notebook with decorative cover",
    "\U0001f4d5": "closed book",
    "\U0001f4d6": "open book",
    "\U0001f4d7": "green book",
    "\U0001f4d8": "blue book",
    "\U0001f4d9": "orange book",
    "\U0001f4da": "books",
    "\U0001f4d3": "notebook",
    "\U0001f4d2": "ledger",
    "\U0001f4c3": "page with curl",
    "\U0001f4dc": "scroll",
    "\U0001f4c4": "page facing up",
    "\U0001f4f0": "newspaper",
    "\U0001f5de": "rolled-up newspaper",
    "\U0001f4d1": "bookmark tabs",
    "\U0001f516": "bookmark",
    "\U0001f3f7": "label",
    # money
    "\U0001f4b0": "money bag",
    "\U0001fa99": "coin",
    "\U0001f4b4": "yen banknote",
    "\U0001f4b5": "dollar banknote",
    "\U0001f4b6": "euro banknote",
    "\U0001f4b7": "pound banknote",
    "\U0001f4b8": "money with wings",
    "\U0001f4b3": "credit card",
    "\U0001f9fe": "receipt",
    "\U0001f4b9": "chart increasing with yen",
    # mail
    "\u2709": "envelope",
    "\U0001f4e7": "e-mail",
    "\U0001f4e8": "incoming envelope",
    "\U0001f4e9": "envelope with arrow",
    "\U0001f4e4": "outbox tray",
    "\U0001f4e5": "inbox tray",
    "\U0001f4e6": "package",
    "\U0001f4eb": "closed mailbox with raised flag",
    "\U0001f4ea": "closed mailbox with lowered flag",
    "\U0001f4ec": "open mailbox with raised flag",
    "\U0001f4ed": "open mailbox with lowered flag",
    "\U0001f4ee": "postbox",
    "\U0001f5f3": "ballot box with ballot",
    # writing
    "\u270f": "pencil",
    "\u2712": "black nib",
    "\U0001f58b": "fountain pen",
    "\U0001f58a": "pen",
    "\U0001f58c": "paintbrush",
    "\U0001f58d": "crayon",
    "\U0001f4dd": "memo",
    # office
    "\U0001f4bc": "briefcase",
    "\U0001f4c1": "file folder",
    "\U0001f4c2": "open file folder",
    "\U0001f5c2": "card index dividers",
    "\U0001f4c5": "calendar",
    "\U0001f4c6": "tear-off calendar",
    "\U0001f5d2": "spiral notepad",
    "\U0001f5d3": "spiral calendar",
    "\U0001f4c7": "card index",
    "\U0001f4c8": "chart increasing",
    "\U0001f4c9": "chart decreasing",
    "\U0001f4ca": "bar chart",
    "\U0001f4cb": "clipboard",
    "\U0001f4cc": "pushpin",
    "\U0001f4cd": "round pushpin",
    "\U0001f4ce": "paperclip",
    "\U0001f587": "linked paperclips",
    "\U0001f4cf": "straight ruler",
    "\U0001f4d0": "triangular ruler",
    "\u2702": "scissors",
    "\U0001f5c3": "card file box",
    "\U0001f5c4": "file cabinet",
    "\U0001f5d1": "wastebasket",
    # lock
    "\U0001f512": "locked",
    "\U0001f513": "unlocked",
    "\U0001f50f": "locked with pen",
    "\U0001f510": "locked with key",
    "\U0001f511": "key",
    "\U0001f5dd": "old key",
    # tool
    "\U0001f528": "hammer",
    "\U0001fa93": "axe",
    "\u26cf": "pick",
    "\u2692": "hammer and pick",
    "\U0001f6e0": "hammer and wrench",
    "\U0001f5e1": "dagger",
    "\u2694": "crossed swords",
    "\U0001f4a3": "bomb",
    "\U0001fa83": "boomerang",
    "\U0001f3f9": "bow and arrow",
    "\U0001f6e1": "shield",
    "\U0001fa9a": "carpentry saw",
    "\U0001f527": "wrench",
    "\U0001fa9b": "screwdriver",
    "\U0001f529": "nut and bolt",
    "\u2699": "gear",
    "\U0001f5dc": "clamp",
    "\u2696": "balance scale",
    "\U0001f9af": "white cane",
    "\U0001f517": "link",
    "\u26d3\ufe0f\u200d\U0001f4a5": "broken chain",
    "\u26d3": "chains",
    "\U0001fa9d": "hook",
    "\U0001f9f0": "toolbox",
    "\U0001f9f2": "magnet",
    "\U0001fa9c": "ladder",
    "\U0001fa8f": "⊛ shovel",
    # science
    "\u2697": "alembic",
    "\U0001f9ea": "test tube",
    "\U0001f9eb": "petri dish",
    "\U0001f9ec": "dna",
    "\U0001f52c": "microscope",
    "\U0001f52d": "telescope",
    "\U0001f4e1": "satellite antenna",
    # medical
    "\U0001f489": "syringe",
    "\U0001fa78": "drop of blood",
    "\U0001f48a": "pill",
    "\U0001fa79": "adhesive bandage",
    "\U0001fa7c": "crutch",
    "\U0001fa7a": "stethoscope",
    "\U0001fa7b": "x-ray",
    # household
    "\U0001f6aa": "door",
    "\U0001f6d7": "elevator",
    "\U0001fa9e": "mirror",
    "\U0001fa9f": "window",
    "\U0001f6cf": "bed",
    "\U0001f6cb": "couch and lamp",
    "\U0001fa91": "chair",
    "\U0001f6bd": "toilet",
    "\U0001faa0": "plunger",
    "\U0001f6bf": "shower",
    "\U0001f6c1": "bathtub",
    "\U0001faa4": "mouse trap",
    "\U0001fa92": "razor",
    "\U0001f9f4": "lotion bottle",
    "\U0001f9f7": "safety pin",
    "\U0001f9f9": "broom",
    "\U0001f9fa": "basket",
    "\U0001f9fb": "roll of paper",
    "\U0001faa3": "bucket",
    "\U0001f9fc": "soap",
    "\U0001fae7": "bubbles",
    "\U0001faa5": "toothbrush",
    "\U0001f9fd": "sponge",
    "\U0001f9ef": "fire extinguisher",
    "\U0001f6d2": "shopping cart",
    # other - object
    "\U0001f6ac": "cigarette",
    "\u26b0": "coffin",
    "\U0001faa6": "headstone",
    "\u26b1": "funeral urn",
    "\U0001f9ff": "nazar amulet",
    "\U0001faac": "hamsa",
    "\U0001f5ff": "moai",
    "\U0001faa7": "placard",
    "\U0001faaa": "identification card",
    # Symbols
    # transport-sign
    "\U0001f3e7": "ATM sign",
    "\U0001f6ae": "litter in bin sign",
    "\U0001f6b0": "potable water",
    "\u267f": "wheelchair symbol",
    "\U0001f6b9": "men’s room",
    "\U0001f6ba": "women’s room",
    "\U0001f6bb": "restroom",
    "\U0001f6bc": "baby symbol",
    "\U0001f6be": "water closet",
    "\U0001f6c2": "passport control",
    "\U0001f6c3": "customs",
    "\U0001f6c4": "baggage claim",
    "\U0001f6c5": "left luggage",
    # warning
    "\u26a0": "warning",
    "\U0001f6b8": "children crossing",
    "\u26d4": "no entry",
    "\U0001f6ab": "prohibited",
    "\U0001f6b3": "no bicycles",
    "\U0001f6ad": "no smoking",
    "\U0001f6af": "no littering",
    "\U0001f6b1": "non-potable water",
    "\U0001f6b7": "no pedestrians",
    "\U0001f4f5": "no mobile phones",
    "\U0001f51e": "no one under eighteen",
    "\u2622": "radioactive",
    "\u2623": "biohazard",
    # arrow
    "\u2b06": "up arrow",
    "\u2197": "up-right arrow",
    "\u27a1": "right arrow",
    "\u2198": "down-right arrow",
    "\u2b07": "down arrow",
    "\u2199": "down-left arrow",
    "\u2b05": "left arrow",
    "\u2196": "up-left arrow",
    "\u2195": "up-down arrow",
    "\u2194": "left-right arrow",
    "\u21a9": "right arrow curving left",
    "\u21aa": "left arrow curving right",
    "\u2934": "right arrow curving up",
    "\u2935": "right arrow curving down",
    "\U0001f503": "clockwise vertical arrows",
    "\U0001f504": "counterclockwise arrows button",
    "\U0001f519": "BACK arrow",
    "\U0001f51a": "END arrow",
    "\U0001f51b": "ON! arrow",
    "\U0001f51c": "SOON arrow",
    "\U0001f51d": "TOP arrow",
    # religion
    "\U0001f6d0": "place of worship",
    "\u269b": "atom symbol",
    "\U0001f549": "om",
    "\u2721": "star of David",
    "\u2638": "wheel of dharma",
    "\u262f": "yin yang",
    "\u271d": "latin cross",
    "\u2626": "orthodox cross",
    "\u262a": "star and crescent",
    "\u262e": "peace symbol",
    "\U0001f54e": "menorah",
    "\U0001f52f": "dotted six-pointed star",
    "\U0001faaf": "khanda",
    # zodiac
    "\u2648": "Aries",
    "\u2649": "Taurus",
    "\u264a": "Gemini",
    "\u264b": "Cancer",
    "\u264c": "Leo",
    "\u264d": "Virgo",
    "\u264e": "Libra",
    "\u264f": "Scorpio",
    "\u2650": "Sagittarius",
    "\u2651": "Capricorn",
    "\u2652": "Aquarius",
    "\u2653": "Pisces",
    "\u26ce": "Ophiuchus",
    # av-symbol
    "\U0001f500": "shuffle tracks button",
    "\U0001f501": "repeat button",
    "\U0001f502": "repeat single button",
    "\u25b6": "play button",
    "\u23e9": "fast-forward button",
    "\u23ed": "next track button",
    "\u23ef": "play or pause button",
    "\u25c0": "reverse button",
    "\u23ea": "fast reverse button",
    "\u23ee": "last track button",
    "\U0001f53c": "upwards button",
    "\u23eb": "fast up button",
    "\U0001f53d": "downwards button",
    "\u23ec": "fast down button",
    "\u23f8": "pause button",
    "\u23f9": "stop button",
    "\u23fa": "record button",
    "\u23cf": "eject button",
    "\U0001f3a6": "cinema",
    "\U0001f505": "dim button",
    "\U0001f506": "bright button",
    "\U0001f4f6": "antenna bars",
    "\U0001f6dc": "wireless",
    "\U0001f4f3": "vibration mode",
    "\U0001f4f4": "mobile phone off",
    # gender
    "\u2640": "female sign",
    "\u2642": "male sign",
    "\u26a7": "transgender symbol",
    # math
    "\u2716": "multiply",
    "\u2795": "plus",
    "\u2796": "minus",
    "\u2797": "divide",
    "\U0001f7f0": "heavy equals sign",
    "\u267e": "infinity",
    # punctuation
    "\u203c": "double exclamation mark",
    "\u2049": "exclamation question mark",
    "\u2753": "red question mark",
    "\u2754": "white question mark",
    "\u2755": "white exclamation mark",
    "\u2757": "red exclamation mark",
    "\u3030": "wavy dash",
    # currency
    "\U0001f4b1": "currency exchange",
    "\U0001f4b2": "heavy dollar sign",
    # other-symbol
    "\u2695": "medical symbol",
    "\u267b": "recycling symbol",
    "\u269c": "fleur-de-lis",
    "\U0001f531": "trident emblem",
    "\U0001f4db": "name badge",
    "\U0001f530": "Japanese symbol for beginner",
    "\u2b55": "hollow red circle",
    "\u2705": "check mark button",
    "\u2611": "check box with check",
    "\u2714": "check mark",
    "\u274c": "cross mark",
    "\u274e": "cross mark button",
    "\u27b0": "curly loop",
    "\u27bf": "double curly loop",
    "\u303d": "part alternation mark",
    "\u2733": "eight-spoked asterisk",
    "\u2734": "eight-pointed star",
    "\u2747": "sparkle",
    "\u00a9": "copyright",
    "\u00ae": "registered",
    "\u2122": "trade mark",
    "\U0001fadf": "splatter",
    # keycap
    "#\ufe0f\u20e3": "keycap: #",
    "*\ufe0f\u20e3": "keycap: *",
    "0\ufe0f\u20e3": "keycap: 0",
    "1\ufe0f\u20e3": "keycap: 1",
    "2\ufe0f\u20e3": "keycap: 2",
    "3\ufe0f\u20e3": "keycap: 3",
    "4\ufe0f\u20e3": "keycap: 4",
    "5\ufe0f\u20e3": "keycap: 5",
    "6\ufe0f\u20e3": "keycap: 6",
    "7\ufe0f\u20e3": "keycap: 7",
    "8\ufe0f\u20e3": "keycap: 8",
    "9\ufe0f\u20e3": "keycap: 9",
    "\U0001f51f": "keycap: 10",
    # alphanum
    "\U0001f520": "input latin uppercase",
    "\U0001f521": "input latin lowercase",
    "\U0001f522": "input numbers",
    "\U0001f523": "input symbols",
    "\U0001f524": "input latin letters",
    "\U0001f170": "A button (blood type)",
    "\U0001f18e": "AB button (blood type)",
    "\U0001f171": "B button (blood type)",
    "\U0001f191": "CL button",
    "\U0001f192": "COOL button",
    "\U0001f193": "FREE button",
    "\u2139": "information",
    "\U0001f194": "ID button",
    "\u24c2": "circled M",
    "\U0001f195": "NEW button",
    "\U0001f196": "NG button",
    "\U0001f17e": "O button (blood type)",
    "\U0001f197": "OK button",
    "\U0001f17f": "P button",
    "\U0001f198": "SOS button",
    "\U0001f199": "UP! button",
    "\U0001f19a": "VS button",
    "\U0001f201": "Japanese “here” button",
    "\U0001f202": "Japanese “service charge” button",
    "\U0001f237": "Japanese “monthly amount” button",
    "\U0001f236": "Japanese “not free of charge” button",
    "\U0001f22f": "Japanese “reserved” button",
    "\U0001f250": "Japanese “bargain” button",
    "\U0001f239": "Japanese “discount” button",
    "\U0001f21a": "Japanese “free of charge” button",
    "\U0001f232": "Japanese “prohibited” button",
    "\U0001f251": "Japanese “acceptable” button",
    "\U0001f238": "Japanese “application” button",
    "\U0001f234": "Japanese “passing grade” button",
    "\U0001f233": "Japanese “vacancy” button",
    "\u3297": "Japanese “congratulations” button",
    "\u3299": "Japanese “secret” button",
    "\U0001f23a": "Japanese “open for business” button",
    "\U0001f235": "Japanese “no vacancy” button",
    # geometric
    "\U0001f534": "red circle",
    "\U0001f7e0": "orange circle",
    "\U0001f7e1": "yellow circle",
    "\U0001f7e2": "green circle",
    "\U0001f535": "blue circle",
    "\U0001f7e3": "purple circle",
    "\U0001f7e4": "brown circle",
    "\u26ab": "black circle",
    "\u26aa": "white circle",
    "\U0001f7e5": "red square",
    "\U0001f7e7": "orange square",
    "\U0001f7e8": "yellow square",
    "\U0001f7e9": "green square",
    "\U0001f7e6": "blue square",
    "\U0001f7ea": "purple square",
    "\U0001f7eb": "brown square",
    "\u2b1b": "black large square",
    "\u2b1c": "white large square",
    "\u25fc": "black medium square",
    "\u25fb": "white medium square",
    "\u25fe": "black medium-small square",
    "\u25fd": "white medium-small square",
    "\u25aa": "black small square",
    "\u25ab": "white small square",
    "\U0001f536": "large orange diamond",
    "\U0001f537": "large blue diamond",
    "\U0001f538": "small orange diamond",
    "\U0001f539": "small blue diamond",
    "\U0001f53a": "red triangle pointed up",
    "\U0001f53b": "red triangle pointed down",
    "\U0001f4a0": "diamond with a dot",
    "\U0001f518": "radio button",
    "\U0001f533": "white square button",
    "\U0001f532": "black square button",
    # Flags
    # flag
    "\U0001f3c1": "chequered flag",
    "\U0001f6a9": "triangular flag",
    "\U0001f38c": "crossed flags",
    "\U0001f3f4": "black flag",
    "\U0001f3f3": "white flag",
    "\U0001f3f3\ufe0f\u200d\U0001f308": "rainbow flag",
    "\U0001f3f3\ufe0f\u200d\u26a7\ufe0f": "transgender flag",
    "\U0001f3f4\u200d\u2620\ufe0f": "pirate flag",
    # country-flag
    "\U0001f1e6\U0001f1e8": "flag: Ascension Island",
    "\U0001f1e6\U0001f1e9": "flag: Andorra",
    "\U0001f1e6\U0001f1ea": "flag: United Arab Emirates",
    "\U0001f1e6\U0001f1eb": "flag: Afghanistan",
    "\U0001f1e6\U0001f1ec": "flag: Antigua & Barbuda",
    "\U0001f1e6\U0001f1ee": "flag: Anguilla",
    "\U0001f1e6\U0001f1f1": "flag: Albania",
    "\U0001f1e6\U0001f1f2": "flag: Armenia",
    "\U0001f1e6\U0001f1f4": "flag: Angola",
    "\U0001f1e6\U0001f1f6": "flag: Antarctica",
    "\U0001f1e6\U0001f1f7": "flag: Argentina",
    "\U0001f1e6\U0001f1f8": "flag: American Samoa",
    "\U0001f1e6\U0001f1f9": "flag: Austria",
    "\U0001f1e6\U0001f1fa": "flag: Australia",
    "\U0001f1e6\U0001f1fc": "flag: Aruba",
    "\U0001f1e6\U0001f1fd": "flag: Aland Islands",
    "\U0001f1e6\U0001f1ff": "flag: Azerbaijan",
    "\U0001f1e7\U0001f1e6": "flag: Bosnia & Herzegovina",
    "\U0001f1e7\U0001f1e7": "flag: Barbados",
    "\U0001f1e7\U0001f1e9": "flag: Bangladesh",
    "\U0001f1e7\U0001f1ea": "flag: Belgium",
    "\U0001f1e7\U0001f1eb": "flag: Burkina Faso",
    "\U0001f1e7\U0001f1ec": "flag: Bulgaria",
    "\U0001f1e7\U0001f1ed": "flag: Bahrain",
    "\U0001f1e7\U0001f1ee": "flag: Burundi",
    "\U0001f1e7\U0001f1ef": "flag: Benin",
    "\U0001f1e7\U0001f1f1": "flag: St. Barthelemy",
    "\U0001f1e7\U0001f1f2": "flag: Bermuda",
    "\U0001f1e7\U0001f1f3": "flag: Brunei",
    "\U0001f1e7\U0001f1f4": "flag: Bolivia",
    "\U0001f1e7\U0001f1f6": "flag: Caribbean Netherlands",
    "\U0001f1e7\U0001f1f7": "flag: Brazil",
    "\U0001f1e7\U0001f1f8": "flag: Bahamas",
    "\U0001f1e7\U0001f1f9": "flag: Bhutan",
    "\U0001f1e7\U0001f1fb": "flag: Bouvet Island",
    "\U0001f1e7\U0001f1fc": "flag: Botswana",
    "\U0001f1e7\U0001f1fe": "flag: Belarus",
    "\U0001f1e7\U0001f1ff": "flag: Belize",
    "\U0001f1e8\U0001f1e6": "flag: Canada",
    "\U0001f1e8\U0001f1e8": "flag: Cocos (Keeling) Islands",
    "\U0001f1e8\U0001f1e9": "flag: Congo - Kinshasa",
    "\U0001f1e8\U0001f1eb": "flag: Central African Republic",
    "\U0001f1e8\U0001f1ec": "flag: Congo - Brazzaville",
    "\U0001f1e8\U0001f1ed": "flag: Switzerland",
    "\U0001f1e8\U0001f1ee": "flag: Cote d’Ivoire",
    "\U0001f1e8\U0001f1f0": "flag: Cook Islands",
    "\U0001f1e8\U0001f1f1": "flag: Chile",
    "\U0001f1e8\U0001f1f2": "flag: Cameroon",
    "\U0001f1e8\U0001f1f3": "flag: China",
    "\U0001f1e8\U0001f1f4": "flag: Colombia",
    "\U0001f1e8\U0001f1f5": "flag: Clipperton Island",
    "\U0001f1e8\U0001f1f6": "flag: Sark",
    "\U0001f1e8\U0001f1f7": "flag: Costa Rica",
    "\U0001f1e8\U0001f1fa": "flag: Cuba",
    "\U0001f1e8\U0001f1fb": "flag: Cape Verde",
    "\U0001f1e8\U0001f1fc": "flag: Curacao",
    "\U0001f1e8\U0001f1fd": "flag: Christmas Island",
    "\U0001f1e8\U0001f1fe": "flag: Cyprus",
    "\U0001f1e8\U0001f1ff": "flag: Czechia",
    "\U0001f1e9\U0001f1ea": "flag: Germany",
    "\U0001f1e9\U0001f1ec": "flag: Diego Garcia",
    "\U0001f1e9\U0001f1ef": "flag: Djibouti",
    "\U0001f1e9\U0001f1f0": "flag: Denmark",
    "\U0001f1e9\U0001f1f2": "flag: Dominica",
    "\U0001f1e9\U0001f1f4": "flag: Dominican Republic",
    "\U0001f1e9\U0001f1ff": "flag: Algeria",
    "\U0001f1ea\U0001f1e6": "flag: Ceuta & Melilla",
    "\U0001f1ea\U0001f1e8": "flag: Ecuador",
    "\U0001f1ea\U0001f1ea": "flag: Estonia",
    "\U0001f1ea\U0001f1ec": "flag: Egypt",
    "\U0001f1ea\U0001f1ed": "flag: Western Sahara",
    "\U0001f1ea\U0001f1f7": "flag: Eritrea",
    "\U0001f1ea\U0001f1f8": "flag: Spain",
    "\U0001f1ea\U0001f1f9": "flag: Ethiopia",
    "\U0001f1ea\U0001f1fa": "flag: European Union",
    "\U0001f1eb\U0001f1ee": "flag: Finland",
    "\U0001f1eb\U0001f1ef": "flag: Fiji",
    "\U0001f1eb\U0001f1f0": "flag: Falkland Islands",
    "\U0001f1eb\U0001f1f2": "flag: Micronesia",
    "\U0001f1eb\U0001f1f4": "flag: Faroe Islands",
    "\U0001f1eb\U0001f1f7": "flag: France",
    "\U0001f1ec\U0001f1e6": "flag: Gabon",
    "\U0001f1ec\U0001f1e7": "flag: United Kingdom",
    "\U0001f1ec\U0001f1e9": "flag: Grenada",
    "\U0001f1ec\U0001f1ea": "flag: Georgia",
    "\U0001f1ec\U0001f1eb": "flag: French Guiana",
    "\U0001f1ec\U0001f1ec": "flag: Guernsey",
    "\U0001f1ec\U0001f1ed": "flag: Ghana",
    "\U0001f1ec\U0001f1ee": "flag: Gibraltar",
    "\U0001f1ec\U0001f1f1": "flag: Greenland",
    "\U0001f1ec\U0001f1f2": "flag: Gambia",
    "\U0001f1ec\U0001f1f3": "flag: Guinea",
    "\U0001f1ec\U0001f1f5": "flag: Guadeloupe",
    "\U0001f1ec\U0001f1f6": "flag: Equatorial Guinea",
    "\U0001f1ec\U0001f1f7": "flag: Greece",
    "\U0001f1ec\U0001f1f8": "flag: South Georgia & South Sandwich Islands",
    "\U0001f1ec\U0001f1f9": "flag: Guatemala",
    "\U0001f1ec\U0001f1fa": "flag: Guam",
    "\U0001f1ec\U0001f1fc": "flag: Guinea-Bissau",
    "\U0001f1ec\U0001f1fe": "flag: Guyana",
    "\U0001f1ed\U0001f1f0": "flag: Hong Kong SAR China",
    "\U0001f1ed\U0001f1f2": "flag: Heard & McDonald Islands",
    "\U0001f1ed\U0001f1f3": "flag: Honduras",
    "\U0001f1ed\U0001f1f7": "flag: Croatia",
    "\U0001f1ed\U0001f1f9": "flag: Haiti",
    "\U0001f1ed\U0001f1fa": "flag: Hungary",
    "\U0001f1ee\U0001f1e8": "flag: Canary Islands",
    "\U0001f1ee\U0001f1e9": "flag: Indonesia",
    "\U0001f1ee\U0001f1ea": "flag: Ireland",
    "\U0001f1ee\U0001f1f1": "flag: Israel",
    "\U0001f1ee\U0001f1f2": "flag: Isle of Man",
    "\U0001f1ee\U0001f1f3": "flag: India",
    "\U0001f1ee\U0001f1f4": "flag: British Indian Ocean Territory",
    "\U0001f1ee\U0001f1f6": "flag: Iraq",
    "\U0001f1ee\U0001f1f7": "flag: Iran",
    "\U0001f1ee\U0001f1f8": "flag: Iceland",
    "\U0001f1ee\U0001f1f9": "flag: Italy",
    "\U0001f1ef\U0001f1ea": "flag: Jersey",
    "\U0001f1ef\U0001f1f2": "flag: Jamaica",
    "\U0001f1ef\U0001f1f4": "flag: Jordan",
    "\U0001f1ef\U0001f1f5": "flag: Japan",
    "\U0001f1f0\U0001f1ea": "flag: Kenya",
    "\U0001f1f0\U0001f1ec": "flag: Kyrgyzstan",
    "\U0001f1f0\U0001f1ed": "flag: Cambodia",
    "\U0001f1f0\U0001f1ee": "flag: Kiribati",
    "\U0001f1f0\U0001f1f2": "flag: Comoros",
    "\U0001f1f0\U0001f1f3": "flag: St. Kitts & Nevis",
    "\U0001f1f0\U0001f1f5": "flag: North Korea",
    "\U0001f1f0\U0001f1f7": "flag: South Korea",
    "\U0001f1f0\U0001f1fc": "flag: Kuwait",
    "\U0001f1f0\U0001f1fe": "flag: Cayman Islands",
    "\U0001f1f0\U0001f1ff": "flag: Kazakhstan",
    "\U0001f1f1\U0001f1e6": "flag: Laos",
    "\U0001f1f1\U0001f1e7": "flag: Lebanon",
    "\U0001f1f1\U0001f1e8": "flag: St. Lucia",
    "\U0001f1f1\U0001f1ee": "flag: Liechtenstein",
    "\U0001f1f1\U0001f1f0": "flag: Sri Lanka",
    "\U0001f1f1\U0001f1f7": "flag: Liberia",
    "\U0001f1f1\U0001f1f8": "flag: Lesotho",
    "\U0001f1f1\U0001f1f9": "flag: Lithuania",
    "\U0001f1f1\U0001f1fa": "flag: Luxembourg",
    "\U0001f1f1\U0001f1fb": "flag: Latvia",
    "\U0001f1f1\U0001f1fe": "flag: Libya",
    "\U0001f1f2\U0001f1e6": "flag: Morocco",
    "\U0001f1f2\U0001f1e8": "flag: Monaco",
    "\U0001f1f2\U0001f1e9": "flag: Moldova",
    "\U0001f1f2\U0001f1ea": "flag: Montenegro",
    "\U0001f1f2\U0001f1eb": "flag: St. Martin",
    "\U0001f1f2\U0001f1ec": "flag: Madagascar",
    "\U0001f1f2\U0001f1ed": "flag: Marshall Islands",
    "\U0001f1f2\U0001f1f0": "flag: North Macedonia",
    "\U0001f1f2\U0001f1f1": "flag: Mali",
    "\U0001f1f2\U0001f1f2": "flag: Myanmar (Burma)",
    "\U0001f1f2\U0001f1f3": "flag: Mongolia",
    "\U0001f1f2\U0001f1f4": "flag: Macao SAR China",
    "\U0001f1f2\U0001f1f5": "flag: Northern Mariana Islands",
    "\U0001f1f2\U0001f1f6": "flag: Martinique",
    "\U0001f1f2\U0001f1f7": "flag: Mauritania",
    "\U0001f1f2\U0001f1f8": "flag: Montserrat",
    "\U0001f1f2\U0001f1f9": "flag: Malta",
    "\U0001f1f2\U0001f1fa": "flag: Mauritius",
    "\U0001f1f2\U0001f1fb": "flag: Maldives",
    "\U0001f1f2\U0001f1fc": "flag: Malawi",
    "\U0001f1f2\U0001f1fd": "flag: Mexico",
    "\U0001f1f2\U0001f1fe": "flag: Malaysia",
    "\U0001f1f2\U0001f1ff": "flag: Mozambique",
    "\U0001f1f3\U0001f1e6": "flag: Namibia",
    "\U0001f1f3\U0001f1e8": "flag: New Caledonia",
    "\U0001f1f3\U0001f1ea": "flag: Niger",
    "\U0001f1f3\U0001f1eb": "flag: Norfolk Island",
    "\U0001f1f3\U0001f1ec": "flag: Nigeria",
    "\U0001f1f3\U0001f1ee": "flag: Nicaragua",
    "\U0001f1f3\U0001f1f1": "flag: Netherlands",
    "\U0001f1f3\U0001f1f4": "flag: Norway",
    "\U0001f1f3\U0001f1f5": "flag: Nepal",
    "\U0001f1f3\U0001f1f7": "flag: Nauru",
    "\U0001f1f3\U0001f1fa": "flag: Niue",
    "\U0001f1f3\U0001f1ff": "flag: New Zealand",
    "\U0001f1f4\U0001f1f2": "flag: Oman",
    "\U0001f1f5\U0001f1e6": "flag: Panama",
    "\U0001f1f5\U0001f1ea": "flag: Peru",
    "\U0001f1f5\U0001f1eb": "flag: French Polynesia",
    "\U0001f1f5\U0001f1ec": "flag: Papua New Guinea",
    "\U0001f1f5\U0001f1ed": "flag: Philippines",
    "\U0001f1f5\U0001f1f0": "flag: Pakistan",
    "\U0001f1f5\U0001f1f1": "flag: Poland",
    "\U0001f1f5\U0001f1f2": "flag: St. Pierre & Miquelon",
    "\U0001f1f5\U0001f1f3": "flag: Pitcairn Islands",
    "\U0001f1f5\U0001f1f7": "flag: Puerto Rico",
    "\U0001f1f5\U0001f1f8": "flag: Palestinian Territories",
    "\U0001f1f5\U0001f1f9": "flag: Portugal",
    "\U0001f1f5\U0001f1fc": "flag: Palau",
    "\U0001f1f5\U0001f1fe": "flag: Paraguay",
    "\U0001f1f6\U0001f1e6": "flag: Qatar",
    "\U0001f1f7\U0001f1ea": "flag: Reunion",
    "\U0001f1f7\U0001f1f4": "flag: Romania",
    "\U0001f1f7\U0001f1f8": "flag: Serbia",
    "\U0001f1f7\U0001f1fa": "flag: Russia",
    "\U0001f1f7\U0001f1fc": "flag: Rwanda",
    "\U0001f1f8\U0001f1e6": "flag: Saudi Arabia",
    "\U0001f1f8\U0001f1e7": "flag: Solomon Islands",
    "\U0001f1f8\U0001f1e8": "flag: Seychelles",
    "\U0001f1f8\U0001f1e9": "flag: Sudan",
    "\U0001f1f8\U0001f1ea": "flag: Sweden",
    "\U0001f1f8\U0001f1ec": "flag: Singapore",
    "\U0001f1f8\U0001f1ed": "flag: St. Helena",
    "\U0001f1f8\U0001f1ee": "flag: Slovenia",
    "\U0001f1f8\U0001f1ef": "flag: Svalbard & Jan Mayen",
    "\U0001f1f8\U0001f1f0": "flag: Slovakia",
    "\U0001f1f8\U0001f1f1": "flag: Sierra Leone",
    "\U0001f1f8\U0001f1f2": "flag: San Marino",
    "\U0001f1f8\U0001f1f3": "flag: Senegal",
    "\U0001f1f8\U0001f1f4": "flag: Somalia",
    "\U0001f1f8\U0001f1f7": "flag: Suriname",
    "\U0001f1f8\U0001f1f8": "flag: South Sudan",
    "\U0001f1f8\U0001f1f9": "flag: Sao Tome & Principe",
    "\U0001f1f8\U0001f1fb": "flag: El Salvador",
    "\U0001f1f8\U0001f1fd": "flag: Sint Maarten",
    "\U0001f1f8\U0001f1fe": "flag: Syria",
    "\U0001f1f8\U0001f1ff": "flag: Eswatini",
    "\U0001f1f9\U0001f1e6": "flag: Tristan da Cunha",
    "\U0001f1f9\U0001f1e8": "flag: Turks & Caicos Islands",
    "\U0001f1f9\U0001f1e9": "flag: Chad",
    "\U0001f1f9\U0001f1eb": "flag: French Southern Territories",
    "\U0001f1f9\U0001f1ec": "flag: Togo",
    "\U0001f1f9\U0001f1ed": "flag: Thailand",
    "\U0001f1f9\U0001f1ef": "flag: Tajikistan",
    "\U0001f1f9\U0001f1f0": "flag: Tokelau",
    "\U0001f1f9\U0001f1f1": "flag: Timor-Leste",
    "\U0001f1f9\U0001f1f2": "flag: Turkmenistan",
    "\U0001f1f9\U0001f1f3": "flag: Tunisia",
    "\U0001f1f9\U0001f1f4": "flag: Tonga",
    "\U0001f1f9\U0001f1f7": "flag: Turkiye",
    "\U0001f1f9\U0001f1f9": "flag: Trinidad & Tobago",
    "\U0001f1f9\U0001f1fb": "flag: Tuvalu",
    "\U0001f1f9\U0001f1fc": "flag: Taiwan",
    "\U0001f1f9\U0001f1ff": "flag: Tanzania",
    "\U0001f1fa\U0001f1e6": "flag: Ukraine",
    "\U0001f1fa\U0001f1ec": "flag: Uganda",
    "\U0001f1fa\U0001f1f2": "flag: U.S. Outlying Islands",
    "\U0001f1fa\U0001f1f3": "flag: United Nations",
    "\U0001f1fa\U0001f1f8": "flag: United States",
    "\U0001f1fa\U0001f1fe": "flag: Uruguay",
    "\U0001f1fa\U0001f1ff": "flag: Uzbekistan",
    "\U0001f1fb\U0001f1e6": "flag: Vatican City",
    "\U0001f1fb\U0001f1e8": "flag: St. Vincent & Grenadines",
    "\U0001f1fb\U0001f1ea": "flag: Venezuela",
    "\U0001f1fb\U0001f1ec": "flag: British Virgin Islands",
    "\U0001f1fb\U0001f1ee": "flag: U.S. Virgin Islands",
    "\U0001f1fb\U0001f1f3": "flag: Vietnam",
    "\U0001f1fb\U0001f1fa": "flag: Vanuatu",
    "\U0001f1fc\U0001f1eb": "flag: Wallis & Futuna",
    "\U0001f1fc\U0001f1f8": "flag: Samoa",
    "\U0001f1fd\U0001f1f0": "flag: Kosovo",
    "\U0001f1fe\U0001f1ea": "flag: Yemen",
    "\U0001f1fe\U0001f1f9": "flag: Mayotte",
    "\U0001f1ff\U0001f1e6": "flag: South Africa",
    "\U0001f1ff\U0001f1f2": "flag: Zambia",
    "\U0001f1ff\U0001f1fc": "flag: Zimbabwe",
    # subdivision-flag
    "\U0001f3f4\U000e0067\U000e0062\U000e0065\U000e006e\U000e0067\U000e007f": "flag: England",
    "\U0001f3f4\U000e0067\U000e0062\U000e0073\U000e0063\U000e0074\U000e007f": "flag: Scotland",
    "\U0001f3f4\U000e0067\U000e0062\U000e0077\U000e006c\U000e0073\U000e007f": "flag: Wales",
}
